@@ -2358,7 +2358,7 @@ static void replace_cleanup(void) {
 	for (i = 0; list[i] != NULL; i++) {
 
 		LIST_FOR_EACH_SAFE(list[i], iter1, iter2, obj) {
-			if (obj->plugin->id == REPLACE_PLUGIN_ID) {
+			if (obj->plugin->id == EVMS_REPLACE_PLUGIN_ID) {
 				rc = cleanup_replace_object(obj);
 			}
 		}
