@@ -167,6 +167,7 @@ size_t        lock_file_size = 0;
 lock_file_t * lock_file;
 
 sem_t   shutdown_sem;
+pthread_t shutdown_tid = 0;
 #define SHUTDOWN_TIMEOUT 30	/* seconds */
 
 boolean is_2_4_kernel;
@@ -819,7 +820,7 @@ int lock_engine(engine_mode_t mode, const char * * msg) {
 	lock_msg[0] = '\0';
 
 	status = stat(ENGINE_LOCK_FILE, &statbuf);
-	
+
 	/*
 	 * Get memory for the lock file contents.
 	 * If the lock file doesn't exist, the stat() above failed and
@@ -978,7 +979,7 @@ start:
 					LOG_PROC_EXIT_INT(ENOMEM);
 					return ENOMEM;
 				}
-				
+
 				/*
 				 * The file name for the pid is symlinked at
 				 * /proc/{pid}/exe
@@ -1128,7 +1129,7 @@ static void free_list_items(list_anchor_t list,
 	void * thing;
 
 	LIST_FOR_EACH_SAFE(list,iter1, iter2, thing) {
-		
+
 		switch (type) {
 		case DISK:
 			{
@@ -1275,6 +1276,8 @@ int evms_close_engine(void) {
 	LOG_PROC_ENTRY();
 
 	if (engine_mode != ENGINE_CLOSED) {
+		pthread_cancel(shutdown_tid);
+		shutdown_tid = 0;
 		close(dm_control_fd);
 		dm_control_fd = 0;
 		evms_free_config();
@@ -1330,7 +1333,7 @@ static void shutdown_engine() {
 		return;
 
 	}
-	
+
 	while (seconds_until_death > 0) {
 		if (engine_mode & ENGINE_WRITE) {
 			sprintf(msg_buf,
@@ -1464,7 +1467,7 @@ static void check_for_2_4_kernel(void)
 	if (fd >= 0) {
 		read(fd, haystack, 256);
 		close(fd);
-		
+
 		ver = strstr(haystack, needle);
 		if (ver) {
 			sscanf(ver, "%*s %d.%d.%d", &major, &minor, &patch);
@@ -1632,7 +1635,7 @@ static void * shutdown_thread(void * arg) {
 		}
 
 	} while ((rc != 0) && (errno == EINTR));
-					
+
 	LOG_DEBUG("Shutdown signal received.\n");
 
 	if (rc == 0) {
@@ -1665,7 +1668,6 @@ int evms_open_engine(char           * node_name,
 		     char           * log_name) {
 	int rc = 0;
 	engine_mode_t open_mode;
-	pthread_t shutdown_tid;
 
 	if (geteuid() != 0) {
 		if (callbacks != NULL) {
@@ -2657,7 +2659,7 @@ int evms_metadata_backup(const char * directory) {
 		engine_user_message(NULL, NULL,
 				    "Error creating metadata backup directory %s.  Error code is %d: %s\n",
 				    metadata_db_name, rc, evms_strerror(rc));
-		
+
 		LOG_PROC_EXIT_INT(rc);
 		return rc;
 	}
@@ -2680,11 +2682,11 @@ int evms_metadata_backup(const char * directory) {
 	if (metadata_db_fd < 0) {
 
 		rc = errno;
-		
+
 		engine_user_message(NULL, NULL,
 				    "Error opening metadata backup file %s.  open() returned error %d: %s\n",
 				    metadata_db_name, rc, strerror(rc));
-		
+
 		LOG_PROC_EXIT_INT(rc);
 		return rc;
 	}
