@@ -36,10 +36,9 @@
 #define EVMS_VOLUME_NAME_SIZE           127
 #define evms_name_f			"x128"
 
-#define IBM_OEM_ID                      8112    // could be anything, but used
+#define EVMS_IBM_OEM_ID                 8112    // could be anything, but used
 						// I=8, B=1, M=12
-						// this one going away as well.
-#define EVMS_OEM_IBM                    IBM_OEM_ID
+#define EVMS_IBM_OEM_NAME		"IBM"
 
 #define EVMS_INITIAL_CRC                0xFFFFFFFF
 #define EVMS_MAGIC_CRC                  0x31415926
@@ -150,7 +149,7 @@ typedef struct evms_version {
 	u_int32_t minor;
 	/* patch level changes when bugs are fixed */
 	u_int32_t patchlevel;
-} evms_version_t;
+} __attribute__ ((packed)) evms_version_t;
 #define evms_version_f \
 	u_int32_f      \
 	u_int32_f      \
@@ -251,7 +250,7 @@ typedef struct evms_feature_header {
 /*232*/ char volume_name[EVMS_VOLUME_NAME_SIZE + 1];
 /*360*/ unsigned char pad[152];
 /*512*/
-} evms_feature_header_t;
+} __attribute__ ((packed)) evms_feature_header_t;
 #define EVMS_FEATURE_HEADER_SECTORS ((sizeof(evms_feature_header_t) + EVMS_VSECTOR_SIZE - 1) / EVMS_VSECTOR_SIZE)
 
 #define evms_feature_header_f \
@@ -442,7 +441,7 @@ typedef struct geometry_s {
 	u_int32_t   bytes_per_sector;
 	u_int64_t   boot_cylinder_limit;
 	u_int64_t   block_size;
-} geometry_t;
+} __attribute__ ((packed)) geometry_t;
 #define geometry_f \
 	u_int64_f \
 	u_int32_f \
@@ -530,7 +529,7 @@ typedef struct progress_s {
 
 	u_int32_t       flags;
 
-} progress_t;
+} __attribute__ ((packed)) progress_t;
 #define progress_f      \
 	int_f           \
 	string_f        \
@@ -711,7 +710,7 @@ typedef enum {
 typedef struct node_info_s {
 	node_flags_t    flags;
 	const char    * node_name;
-} node_info_t;
+} __attribute__ ((packed)) node_info_t;
 #define node_info_f  \
 	node_flags_f \
 	string_f
@@ -720,7 +719,7 @@ typedef struct node_info_s {
 typedef struct node_list_s {
 	u_int32_t       count;
 	node_info_t     node_info[0];
-} node_list_t;
+} __attribute__ ((packed)) node_list_t;
 #define node_list_f "C[" node_info_f "]"
 	
 
