@@ -2946,9 +2946,7 @@ static plugin_functions_t bbr_functions = {
  * Plugin record for BBR segment manager.
  **/
 static plugin_record_t bbr_plugin_record = {
-	.id = SetPluginID(EVMS_OEM_IBM,
-			  EVMS_SEGMENT_MANAGER,
-			  EVMS_BBR_FEATURE_ID),
+	.id = EVMS_BBR_SEG_PLUGIN_ID,
 	.version = {
 		.major = MAJOR_VERSION,
 		.minor = MINOR_VERSION,
@@ -2966,9 +2964,9 @@ static plugin_record_t bbr_plugin_record = {
 			.patchlevel = 0
 		}
 	},
-	.short_name = "BBRseg",
-	.long_name = "Bad Block Relocation Segment Manager",
-	.oem_name = "IBM",
+	.short_name = EVMS_BBR_SEG_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_BBR_SEG_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.plugin = &bbr_functions
 	}
