@@ -34,82 +34,6 @@
 
 
 
-int bsd_init_task(task_context_t * context)
-{
-        LOG_ENTRY();
-        REQUIRE(context != NULL);
-        LOG_EXIT_INT(ENOSYS);
-        return ENOSYS;
-}
-
-
-int bsd_set_objects( task_context_t * context,
-                     list_anchor_t          declined_objects,
-                     task_effect_t  * effect )
-{
-        LOG_ENTRY();
-        REQUIRE(context != NULL);
-        REQUIRE(declined_objects != NULL);
-        REQUIRE(effect != NULL);
-        LOG_EXIT_INT(ENOSYS);
-        return ENOSYS;
-}
-
-
-int bsd_get_option_count(task_context_t * task)
-{
-        int count=0;
-
-        LOG_ENTRY();
-
-        REQUIRE(task != NULL);
-
-        switch (task->action) {
-        
-        case EVMS_Task_Create:
-                count = BSD_CREATE_OPTION_COUNT;
-                break;
-
-        case EVMS_Task_Assign_Plugin:
-                count = BSD_ASSIGN_OPTION_COUNT;
-                break;
-
-        case EVMS_Task_Expand:
-                count = BSD_EXPAND_OPTION_COUNT;
-                break;
-
-        case EVMS_Task_Shrink:
-                count = BSD_SHRINK_OPTION_COUNT;
-                break;
-
-        default:
-                LOG_DEBUG("unsupported task ... task->action = %d\n", task->action);                    
-                count = 0;
-                break;
-        }
-
-        LOG_EXIT_INT(count);
-        return count;
-}
-
-
-int bsd_set_option( task_context_t * context,
-                    u_int32_t        index,
-                    value_t        * value,
-                    task_effect_t  * effect )
-{
-        LOG_ENTRY();
-
-        REQUIRE(context != NULL);
-        REQUIRE(value != NULL);
-        REQUIRE(effect != NULL);
-
-        LOG_EXIT_INT(ENOSYS);
-        return ENOSYS;
-}
-
-
-
 /*
  * Returns segment specific information
  */
@@ -129,18 +53,18 @@ int bsd_get_segment_info( storage_object_t  * object, extended_info_array_t * *
 
                 Info->count = SEG_INFO_COUNT;
 
-                SET_STRING( Info->info[SEG_INFO_NAME_INDEX].name, "Name" );
-                SET_STRING( Info->info[SEG_INFO_NAME_INDEX].title, "Name" );
-                SET_STRING( Info->info[SEG_INFO_NAME_INDEX].desc, "This is the partition name. It must be unique on the system.");
+                Info->info[SEG_INFO_NAME_INDEX].name = EngFncs->engine_strdup( "Name" );
+                Info->info[SEG_INFO_NAME_INDEX].title = EngFncs->engine_strdup( _("Name") );
+                Info->info[SEG_INFO_NAME_INDEX].desc = EngFncs->engine_strdup( _("This is the partition name. It must be unique on the system.") );
                 Info->info[SEG_INFO_NAME_INDEX].type               = EVMS_Type_String;
                 Info->info[SEG_INFO_NAME_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[SEG_INFO_NAME_INDEX].value.s, object->name );
+                Info->info[SEG_INFO_NAME_INDEX].value.s = EngFncs->engine_strdup( object->name );
                 Info->info[SEG_INFO_NAME_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[SEG_INFO_NAME_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[SEG_INFO_SIZE_INDEX].name, "Size" );
-                SET_STRING( Info->info[SEG_INFO_SIZE_INDEX].title, "Size" );
-                SET_STRING( Info->info[SEG_INFO_SIZE_INDEX].desc, "This is the size of the partition in sectors.");
+                Info->info[SEG_INFO_SIZE_INDEX].name = EngFncs->engine_strdup( "Size" );
+                Info->info[SEG_INFO_SIZE_INDEX].title = EngFncs->engine_strdup( _("Size") );
+                Info->info[SEG_INFO_SIZE_INDEX].desc = EngFncs->engine_strdup( _("This is the size of the partition in sectors.") );
                 Info->info[SEG_INFO_SIZE_INDEX].type               = EVMS_Type_Unsigned_Int64;
                 Info->info[SEG_INFO_SIZE_INDEX].unit               = EVMS_Unit_Sectors;
                 Info->info[SEG_INFO_SIZE_INDEX].value.ui64         = object->size;
@@ -149,9 +73,9 @@ int bsd_get_segment_info( storage_object_t  * object, extended_info_array_t * *
                 memset( &Info->info[SEG_INFO_SIZE_INDEX].group, 0, sizeof(group_info_t));
                 Info->info[SEG_INFO_SIZE_INDEX].flags |= EVMS_EINFO_FLAGS_NO_UNIT_CONVERSION;
 
-                SET_STRING( Info->info[SEG_INFO_START_INDEX].name, "Start" );
-                SET_STRING( Info->info[SEG_INFO_START_INDEX].title, "Start LBA" );
-                SET_STRING( Info->info[SEG_INFO_START_INDEX].desc, "This is the sector offset of the partition on the disk, i.e., the logical block address of the first sector of the partition.");
+                Info->info[SEG_INFO_START_INDEX].name = EngFncs->engine_strdup( "Start" );
+                Info->info[SEG_INFO_START_INDEX].title = EngFncs->engine_strdup( _("Start Logical Block Address") );
+                Info->info[SEG_INFO_START_INDEX].desc = EngFncs->engine_strdup( _("This is the sector offset of the partition on the disk, i.e., the logical block address of the first sector of the partition.") );
                 Info->info[SEG_INFO_START_INDEX].type               = EVMS_Type_Unsigned_Int64;
                 Info->info[SEG_INFO_START_INDEX].unit               = EVMS_Unit_None;
                 Info->info[SEG_INFO_START_INDEX].value.ui64         = object->start;
@@ -160,23 +84,23 @@ int bsd_get_segment_info( storage_object_t  * object, extended_info_array_t * *
                 memset( &Info->info[SEG_INFO_START_INDEX].group, 0, sizeof(group_info_t));
 
 
-                SET_STRING( Info->info[SEG_INFO_TYPE_INDEX].name, "Type" );
-                SET_STRING( Info->info[SEG_INFO_TYPE_INDEX].title, "Type" );
-                SET_STRING( Info->info[SEG_INFO_TYPE_INDEX].desc, "Partition type - data, metadata, free.");
+                Info->info[SEG_INFO_TYPE_INDEX].name = EngFncs->engine_strdup( "Type" );
+                Info->info[SEG_INFO_TYPE_INDEX].title = EngFncs->engine_strdup( _("Type") );
+                Info->info[SEG_INFO_TYPE_INDEX].desc = EngFncs->engine_strdup( _("Partition type - data, metadata, free.") );
                 Info->info[SEG_INFO_TYPE_INDEX].type               = EVMS_Type_String;
                 Info->info[SEG_INFO_TYPE_INDEX].unit               = EVMS_Unit_None;
                 Info->info[SEG_INFO_TYPE_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[SEG_INFO_TYPE_INDEX].group, 0, sizeof(group_info_t));
 
                 if ( object->data_type == DATA_TYPE ) {
-                        SET_STRING( Info->info[SEG_INFO_TYPE_INDEX].value.s, "data" );
+                        Info->info[SEG_INFO_TYPE_INDEX].value.s = EngFncs->engine_strdup( _("data") );
                 }
                 else if ( object->data_type == META_DATA_TYPE ) {
-                        SET_STRING( Info->info[SEG_INFO_TYPE_INDEX].value.s, "metadata" );
+                        Info->info[SEG_INFO_TYPE_INDEX].value.s = EngFncs->engine_strdup( _("metadata") );
                         Info->info[SEG_INFO_TYPE_INDEX].flags           = EVMS_EINFO_FLAGS_MORE_INFO_AVAILABLE;
                 }
                 else {
-                        SET_STRING( Info->info[SEG_INFO_TYPE_INDEX].value.s, "unknown" );
+                        Info->info[SEG_INFO_TYPE_INDEX].value.s = EngFncs->engine_strdup( _("unknown") );
                 }
 
                 *info = Info;
@@ -221,23 +145,23 @@ int bsd_get_metadata_info(storage_object_t * object, extended_info_array_t **inf
 
                 Info->count = BSD_LABEL_INFO_COUNT;
 
-                sprintf(geometry_string,"C= %d   H= %d  S= %d", 
-                        DISK_TO_CPU32(disk_label->d_ncylinders), 
-                        DISK_TO_CPU32(disk_label->d_ntracks), 
+                sprintf(geometry_string,"C= %d   H= %d  S= %d",
+                        DISK_TO_CPU32(disk_label->d_ncylinders),
+                        DISK_TO_CPU32(disk_label->d_ntracks),
                         DISK_TO_CPU32(disk_label->d_nsectors));
 
-                SET_STRING( Info->info[BSD_INFO_GEO_INDEX].name, "Geometry" );
-                SET_STRING( Info->info[BSD_INFO_GEO_INDEX].title, "Disk Geometry" );
-                SET_STRING( Info->info[BSD_INFO_GEO_INDEX].desc, "This is the disk geometry reported in the label.");
+                Info->info[BSD_INFO_GEO_INDEX].name = EngFncs->engine_strdup( "Geometry" );
+                Info->info[BSD_INFO_GEO_INDEX].title = EngFncs->engine_strdup( _("Disk Geometry") );
+                Info->info[BSD_INFO_GEO_INDEX].desc = EngFncs->engine_strdup( _("This is the disk geometry reported in the label.") );
                 Info->info[BSD_INFO_GEO_INDEX].type               = EVMS_Type_String;
                 Info->info[BSD_INFO_GEO_INDEX].unit               = EVMS_Unit_None;
                 Info->info[BSD_INFO_GEO_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[BSD_INFO_GEO_INDEX].group, 0, sizeof(group_info_t));
-                SET_STRING( Info->info[BSD_INFO_GEO_INDEX].value.s, geometry_string );                          
+                Info->info[BSD_INFO_GEO_INDEX].value.s = EngFncs->engine_strdup( geometry_string );
 
-                SET_STRING( Info->info[BSD_INFO_SECTORSIZE_INDEX].name, "Sector Size" );
-                SET_STRING( Info->info[BSD_INFO_SECTORSIZE_INDEX].title, "Sector Size" );
-                SET_STRING( Info->info[BSD_INFO_SECTORSIZE_INDEX].desc, "Sector size reported by disk label.");
+                Info->info[BSD_INFO_SECTORSIZE_INDEX].name = EngFncs->engine_strdup( "Sector Size" );
+                Info->info[BSD_INFO_SECTORSIZE_INDEX].title = EngFncs->engine_strdup( _("Sector Size") );
+                Info->info[BSD_INFO_SECTORSIZE_INDEX].desc = EngFncs->engine_strdup( _("Sector size reported by disk label.") );
                 Info->info[BSD_INFO_SECTORSIZE_INDEX].type               = EVMS_Type_Unsigned_Int32;
                 Info->info[BSD_INFO_SECTORSIZE_INDEX].unit               = EVMS_Unit_None;
                 Info->info[BSD_INFO_SECTORSIZE_INDEX].value.ui64         = DISK_TO_CPU32(disk_label->d_secsize);
@@ -245,9 +169,9 @@ int bsd_get_metadata_info(storage_object_t * object, extended_info_array_t **inf
                 Info->info[BSD_INFO_SECTORSIZE_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[BSD_INFO_SECTORSIZE_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[BSD_INFO_PCOUNT_INDEX].name, "Partitions" );
-                SET_STRING( Info->info[BSD_INFO_PCOUNT_INDEX].title, "Partition Count" );
-                SET_STRING( Info->info[BSD_INFO_PCOUNT_INDEX].desc, "The number of partitions reported by the disk label.");
+                Info->info[BSD_INFO_PCOUNT_INDEX].name = EngFncs->engine_strdup( "Partitions" );
+                Info->info[BSD_INFO_PCOUNT_INDEX].title = EngFncs->engine_strdup( _("Partition Count") );
+                Info->info[BSD_INFO_PCOUNT_INDEX].desc = EngFncs->engine_strdup( _("The number of partitions reported by the disk label.") );
                 Info->info[BSD_INFO_PCOUNT_INDEX].type               = EVMS_Type_Unsigned_Int16;
                 Info->info[BSD_INFO_PCOUNT_INDEX].unit               = EVMS_Unit_None;
                 Info->info[BSD_INFO_PCOUNT_INDEX].value.ui64         = DISK_TO_CPU16(disk_label->d_npartitions);
@@ -255,9 +179,9 @@ int bsd_get_metadata_info(storage_object_t * object, extended_info_array_t **inf
                 Info->info[BSD_INFO_PCOUNT_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[BSD_INFO_PCOUNT_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[BSD_INFO_BOOTSIZE_INDEX].name, "Boot Size" );
-                SET_STRING( Info->info[BSD_INFO_BOOTSIZE_INDEX].title, "Boot Area Size" );
-                SET_STRING( Info->info[BSD_INFO_BOOTSIZE_INDEX].desc, "Size of boot area that is reported by the disk label.");
+                Info->info[BSD_INFO_BOOTSIZE_INDEX].name = EngFncs->engine_strdup( "Boot Size" );
+                Info->info[BSD_INFO_BOOTSIZE_INDEX].title = EngFncs->engine_strdup( _("Boot Area Size") );
+                Info->info[BSD_INFO_BOOTSIZE_INDEX].desc = EngFncs->engine_strdup( _("Size of boot area that is reported by the disk label.") );
                 Info->info[BSD_INFO_BOOTSIZE_INDEX].type               = EVMS_Type_Unsigned_Int32;
                 Info->info[BSD_INFO_BOOTSIZE_INDEX].unit               = EVMS_Unit_None;
                 Info->info[BSD_INFO_BOOTSIZE_INDEX].value.ui64         = DISK_TO_CPU32(disk_label->d_bbsize);
@@ -265,9 +189,9 @@ int bsd_get_metadata_info(storage_object_t * object, extended_info_array_t **inf
                 Info->info[BSD_INFO_BOOTSIZE_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[BSD_INFO_BOOTSIZE_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[BSD_INFO_SBSIZE_INDEX].name, "SB Size" );
-                SET_STRING( Info->info[BSD_INFO_SBSIZE_INDEX].title, "Superblock Size" );
-                SET_STRING( Info->info[BSD_INFO_SBSIZE_INDEX].desc, "Size of file system super block that is reported by the disk label.");
+                Info->info[BSD_INFO_SBSIZE_INDEX].name = EngFncs->engine_strdup( "SB Size" );
+                Info->info[BSD_INFO_SBSIZE_INDEX].title = EngFncs->engine_strdup( _("Superblock Size") );
+                Info->info[BSD_INFO_SBSIZE_INDEX].desc = EngFncs->engine_strdup( _("Size of file system super block that is reported by the disk label.") );
                 Info->info[BSD_INFO_SBSIZE_INDEX].type               = EVMS_Type_Unsigned_Int32;
                 Info->info[BSD_INFO_SBSIZE_INDEX].unit               = EVMS_Unit_None;
                 Info->info[BSD_INFO_SBSIZE_INDEX].value.ui64         = DISK_TO_CPU32(disk_label->d_sbsize);
@@ -333,57 +257,59 @@ int bsd_get_plugin_info( char * descriptor_name, extended_info_array_t * * info
                         bsd_plugin->required_plugin_api_version.plugin.minor,
                         bsd_plugin->required_plugin_api_version.plugin.patchlevel );
 
-                SET_STRING( Info->info[PLUGIN_INFO_SNAME_INDEX].name, "ShortName" );
-                SET_STRING( Info->info[PLUGIN_INFO_SNAME_INDEX].title, "Short Name" );
-                SET_STRING( Info->info[PLUGIN_INFO_SNAME_INDEX].desc, "A short name given to this plugin.");
+                Info->info[PLUGIN_INFO_SNAME_INDEX].name = EngFncs->engine_strdup( "ShortName" );
+                Info->info[PLUGIN_INFO_SNAME_INDEX].title = EngFncs->engine_strdup( _("Short Name") );
+                Info->info[PLUGIN_INFO_SNAME_INDEX].desc = EngFncs->engine_strdup( _("A short name given to this plug-in") );
                 Info->info[PLUGIN_INFO_SNAME_INDEX].type               = EVMS_Type_String;
                 Info->info[PLUGIN_INFO_SNAME_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[PLUGIN_INFO_SNAME_INDEX].value.s, bsd_plugin->short_name );
+                Info->info[PLUGIN_INFO_SNAME_INDEX].value.s = EngFncs->engine_strdup( bsd_plugin->short_name );
                 Info->info[PLUGIN_INFO_SNAME_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[PLUGIN_INFO_SNAME_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[PLUGIN_INFO_LNAME_INDEX].name, "LongName" );
-                SET_STRING( Info->info[PLUGIN_INFO_LNAME_INDEX].title, "Long Name" );
-                SET_STRING( Info->info[PLUGIN_INFO_LNAME_INDEX].desc, "A longer and more descriptive name for this plugin.");
+                Info->info[PLUGIN_INFO_LNAME_INDEX].name = EngFncs->engine_strdup( "LongName" );
+                Info->info[PLUGIN_INFO_LNAME_INDEX].title = EngFncs->engine_strdup( _("Long Name") );
+                Info->info[PLUGIN_INFO_LNAME_INDEX].desc = EngFncs->engine_strdup( _("A longer, more descriptive name for this plug-in") );
                 Info->info[PLUGIN_INFO_LNAME_INDEX].type               = EVMS_Type_String;
                 Info->info[PLUGIN_INFO_LNAME_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[PLUGIN_INFO_LNAME_INDEX].value.s, bsd_plugin->long_name );
+                Info->info[PLUGIN_INFO_LNAME_INDEX].value.s = EngFncs->engine_strdup( bsd_plugin->long_name );
                 Info->info[PLUGIN_INFO_LNAME_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[PLUGIN_INFO_LNAME_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[PLUGIN_INFO_TYPE_INDEX].name, "Type" );
-                SET_STRING( Info->info[PLUGIN_INFO_TYPE_INDEX].title, "Plugin Type" );
-                SET_STRING( Info->info[PLUGIN_INFO_TYPE_INDEX].desc, "There are various types of plugins; each responsible for some kind of storage object.");
+                Info->info[PLUGIN_INFO_TYPE_INDEX].name = EngFncs->engine_strdup( "Type" );
+                Info->info[PLUGIN_INFO_TYPE_INDEX].title = EngFncs->engine_strdup( _("Plug-in Type") );
+                Info->info[PLUGIN_INFO_TYPE_INDEX].desc = EngFncs->engine_strdup( _("There are various types of plug-ins, each responsible for some kind of storage object or logical volume.") );
                 Info->info[PLUGIN_INFO_TYPE_INDEX].type               = EVMS_Type_String;
                 Info->info[PLUGIN_INFO_TYPE_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[PLUGIN_INFO_TYPE_INDEX].value.s, "Partition Manager" );
+                Info->info[PLUGIN_INFO_TYPE_INDEX].value.s = EngFncs->engine_strdup( _("Segment Manager") );
                 Info->info[PLUGIN_INFO_TYPE_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[PLUGIN_INFO_TYPE_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[PLUGIN_INFO_VERSION_INDEX].name, "Version" );
-                SET_STRING( Info->info[PLUGIN_INFO_VERSION_INDEX].title, "Plugin Version" );
-                SET_STRING( Info->info[PLUGIN_INFO_VERSION_INDEX].desc, "This is the version number of the plugin.");
+                Info->info[PLUGIN_INFO_VERSION_INDEX].name = EngFncs->engine_strdup( "Version" );
+                Info->info[PLUGIN_INFO_VERSION_INDEX].title = EngFncs->engine_strdup( _("Plug-in Version") );
+                Info->info[PLUGIN_INFO_VERSION_INDEX].desc = EngFncs->engine_strdup( _("This is the version number of the plugin.") );
                 Info->info[PLUGIN_INFO_VERSION_INDEX].type               = EVMS_Type_String;
                 Info->info[PLUGIN_INFO_VERSION_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[PLUGIN_INFO_VERSION_INDEX].value.s, version_string );
+                Info->info[PLUGIN_INFO_VERSION_INDEX].value.s = EngFncs->engine_strdup( version_string );
                 Info->info[PLUGIN_INFO_VERSION_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[PLUGIN_INFO_VERSION_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].name, "Required Engine Services Version" );
-                SET_STRING( Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].title, "Required Engine Services Version" );
-                SET_STRING( Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].desc, "This is the version of the Engine services that this plugin requires. It will not run on older versions of the Engine services.");
+                Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].name = EngFncs->engine_strdup( "Required Engine Services Version" );
+                Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].title = EngFncs->engine_strdup( _("Required Engine Services Version") );
+                Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].desc = EngFncs->engine_strdup( _("This is the version of the Engine services that this plugin requires. "
+												" It will not run on older versions of the Engine services.") );
                 Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].type               = EVMS_Type_String;
                 Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].value.s, required_engine_api_version_string );
+                Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].value.s = EngFncs->engine_strdup( required_engine_api_version_string );
                 Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[PLUGIN_INFO_REQENGSVCVERSION_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].name, "Required Engine Plug-in API Version" );
-                SET_STRING( Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].title, "Required Engine Plug-in API Version" );
-                SET_STRING( Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].desc, "This is the version of the Engine plug-in API that this plugin requires. It will not run on older versions of the Engine plug-in API.");
+                Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].name = EngFncs->engine_strdup( "Required Engine Plug-in API Version" );
+                Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].title = EngFncs->engine_strdup( _("Required Engine Plug-in API Version") );
+                Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].desc = EngFncs->engine_strdup( _("This is the version of the Engine plug-in API that this plugin requires.  "
+												 "It will not run on older versions of the Engine plug-in API.") );
                 Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].type               = EVMS_Type_String;
                 Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].value.s, required_plugin_api_version_string );
+                Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].value.s = EngFncs->engine_strdup( required_plugin_api_version_string );
                 Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].group, 0, sizeof(group_info_t));
 
