@@ -233,8 +233,22 @@ static void get_legacy_config()
 
 static void get_sysfs_config()
 {
+	boolean ignore_sysfs = FALSE;
+
 	LOG_ENTRY();
 
+	EngFncs->get_config_bool("sysfs_devices.ignore_sysfs", &ignore_sysfs);
+	if (ignore_sysfs) {
+		/* Fall back to the legacy_devices section
+		 * if the config file says to ignore sysfs.
+		 */
+		free(sysfs_mount_point);
+		sysfs_mount_point = NULL;
+		get_legacy_config();
+		LOG_EXIT_VOID();
+		return;
+	}
+
 	include_count = 0;
 	includes = NULL;
 	EngFncs->get_config_string_array("sysfs_devices.include",
@@ -1396,35 +1410,54 @@ static int get_geometry(storage_object_t * disk)
 
 	LOG_ENTRY();
 
-	rc = ioctl(ld->fd, HDIO_GETGEO_BIG, &big_geometry);
+	rc = ioctl(ld->fd, HDIO_GETGEO, &geometry);
 	if (rc) {
-		rc = ioctl(ld->fd, HDIO_GETGEO, &geometry);
-		if (!rc) {
-			 big_geometry.heads     = geometry.heads;
-			 big_geometry.sectors   = geometry.sectors;
-			 big_geometry.cylinders = geometry.cylinders;
-			 big_geometry.start     = geometry.start;
-		} else {
+		rc = ioctl(ld->fd, HDIO_GETGEO_BIG, &big_geometry);
+		if (rc) {
 			rc = errno;
 			LOG_DEBUG("Error getting geometry for disk %s: %d: "
 				  "%s.\n", disk->name, rc, strerror(rc));
-			goto out;
+		} else if (big_geometry.start != 0) {
+			/* A disk's geometry must start at offset 0. */
+			LOG_DEBUG("Geometry for disk %s reports a non-zero starting "
+				  "offset. Not a valid disk.\n", disk->name);
+			rc = EINVAL;
+		} else {
+			disk->geometry.cylinders = big_geometry.cylinders;
+			disk->geometry.heads = big_geometry.heads;
+			disk->geometry.sectors_per_track = big_geometry.sectors;
+		}
+	} else {
+		if (geometry.start != 0) {
+			/* A disk's geometry must start at offset 0. */
+			LOG_DEBUG("Geometry for disk %s reports a non-zero starting "
+				  "offset. Not a valid disk.\n", disk->name);
+			rc = EINVAL;
+		} else {
+			/* ala fdisk: never use geometry.cylinders - it is truncated */
+			// disk->geometry.cylinders = geometry.cylinders;
+			disk->geometry.heads = geometry.heads;
+			disk->geometry.sectors_per_track = geometry.sectors;
 		}
 	}
 
-	/* A disk's geometry must start at offset 0. */
-	if (big_geometry.start != 0) {
-		LOG_DEBUG("Geometry for disk %s reports a non-zero starting "
-			  "offset. Not a valid disk.\n", disk->name);
-		rc = EINVAL;
-		goto out;
+	/*
+	 * If the driver answered the ioctl but didn't supply a geometry,
+	 * fill in a default geometry.  This is what fdisk does.
+	 */
+	if (rc == 0) {
+		if (disk->geometry.heads == 0) {
+			disk->geometry.heads = 255;
+		}
+		if (disk->geometry.sectors_per_track == 0) {
+			disk->geometry.sectors_per_track = 63;
+		}
+		if (disk->geometry.cylinders == 0) {
+			disk->geometry.cylinders = disk->size / (255 * 63 *
+								 (disk->geometry.bytes_per_sector / 512));
+		}
 	}
 
-	disk->geometry.cylinders = big_geometry.cylinders;
-	disk->geometry.heads = big_geometry.heads;
-	disk->geometry.sectors_per_track = big_geometry.sectors;
-
-out:
 	LOG_EXIT_INT(rc);
 	return rc;
 }
@@ -1709,6 +1742,9 @@ static int LD_discover(list_anchor_t input_list,
 			continue;
 		}
 
+		/* Get the disk's hard-sector-size. */
+		get_hardsector_size(&working_disk);
+
 		/* Get the disk's geometry. */
 		rc = get_geometry(&working_disk);
 		if (rc) {
@@ -1726,9 +1762,6 @@ static int LD_discover(list_anchor_t input_list,
 			continue;
 		}
 
-		/* Get the disk's hard-sector-size. */
-		get_hardsector_size(&working_disk);
-
 		/* Passed all checks. Create a new disk. */
 		disk = create_logical_disk(&working_disk);
 		if (!disk) {
@@ -2301,7 +2334,7 @@ static int LD_backup_metadata(storage_object_t * disk) {
 
 	LOG_ENTRY();
 
-	if (disk->plugin->id != LDM_PLUGIN_ID_2) {
+	if (disk->plugin->id != EVMS_DISK_PLUGIN_ID) {
 		LOG_ERROR("I don't own object %s.\n", disk->name);
 		LOG_EXIT_INT(EINVAL);
 		return EINVAL;
@@ -2331,7 +2364,7 @@ static plugin_functions_t ft_sysfs = {
 };
 
 plugin_record_t LD_Plugin = {
-	.id = LDM_PLUGIN_ID_2,
+	.id = EVMS_DISK_PLUGIN_ID,
 	.version = {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -2349,9 +2382,9 @@ plugin_record_t LD_Plugin = {
 			.patchlevel	= 0
 		}
 	},
-	.short_name = "LocalDskMgr",
-	.long_name = "Local Disk Manager",
-	.oem_name = "IBM",
+	.short_name = EVMS_DISK_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_DISK_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.plugin = &ft_sysfs
 	},
