@@ -55,6 +55,17 @@ struct hd_big_geometry {
 	unsigned long start;
 };
 
+/**
+ * struct file_handle
+ *
+ * Structure to help keep track of how many open file-handles we
+ * have, and prevent too many from being open at once.
+ **/
+typedef struct file_handle {
+	storage_object_t *disk;
+	list_element_t elem;
+} file_handle_t;
+
 /**
  * struct local_disk
  *
@@ -63,6 +74,7 @@ struct hd_big_geometry {
 typedef struct local_disk {
 	int fd;
 	unsigned int flags;
+	file_handle_t *file_handle;
 } local_disk_t;
 
 #define LD_FLAG_MULTIPATH	(1 << 0)
