@@ -2518,16 +2518,16 @@ static struct plugin_functions_s sft={
 
 static plugin_record_t segmgr_plugin_record = {
 
-	id:                                 SetPluginID(EVMS_OEM_IBM, EVMS_SEGMENT_MANAGER, 1 ),
+	id:                                 EVMS_DOS_PLUGIN_ID,
 
 	version:                            {MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL},
 
 	required_engine_api_version:        {15,0,0},
 	required_plugin_api_version:        {plugin: {13,1,0}},
 
-	short_name:                         "DosSegMgr",
-	long_name:                          "DOS Segment Manager",
-	oem_name:                           "IBM",
+	short_name:                         EVMS_DOS_PLUGIN_SHORT_NAME,
+	long_name:                          EVMS_DOS_PLUGIN_LONG_NAME,
+	oem_name:                           EVMS_IBM_OEM_NAME,
 
 	functions:                          {plugin: &sft},
 
