@@ -28,6 +28,10 @@
 #define HA_USE_IPC
 #endif
 
+#if (HA_MAJOR > 1)
+#define MUST_HAVE_GLIB2
+#endif
+
 /* NOTE:  ENGINE IS THE SLAVE AND DAEMON IS THE MASTER */
 /* NOTE any variable that starts with gl_ is a global variable */
 
@@ -97,7 +101,7 @@ typedef struct {
 
 typedef struct event_s {
 	ece_callback_class_t 	class;
-	size_t			size;		
+	size_t			size;
 	void			*data;
 } event_t;
 
@@ -186,7 +190,7 @@ source_add(destroy_t func, gpointer source)
 	new = g_malloc(sizeof(source_t));
 	new->sr_func = func;
 	new->sr_source = source;
-	
+
   	gl_ece_source = g_slist_append(gl_ece_source, new);
 	LOG_EXIT_VOID();
 }
@@ -462,7 +466,7 @@ register_cleanup(gpointer data, gpointer userdata)
 	LOG_ENTRY();
 	/* note only data has to be freed */
 	g_free(data);
-	
+
 	/* userdata is NULL */
 	ECE_ASSERT(userdata==NULL);
 	LOG_EXIT_VOID();
@@ -557,7 +561,7 @@ unregister_all(void)
 
 /* END OF REGISTRATION RELATION FUNCTIONS */
 
-/*  		BEGIN OF FUNCTIONS 				
+/*  		BEGIN OF FUNCTIONS
  * that distribute the membership events to the registered
  * clients instances
  */
@@ -588,7 +592,7 @@ process_ece_status(const char *orig, const char *status)
 		llm_set_ece_status(orig, FALSE);
 		process_ack(orig, "0", "112" /* EHOSTDOWN */);
 		 /* clean any message fragments
-		  * from that node	
+		  * from that node
 		  */
 		frag_clean(orig);
 		LOG_EXIT_VOID();
@@ -622,7 +626,7 @@ process_ece_status(const char *orig, const char *status)
 		LOG_SERIOUS("Cannot respond to a join message\n");
 		return;
 	}
-	if ((ha_msg_add(h_msg, F_TYPE, T_APICLISTAT) == HA_FAIL)
+	if ((ha_msg_add(h_msg, F_TYPE, ECE_CLIENTSTAT) == HA_FAIL)
 	||(ha_msg_add(h_msg, F_STATUS, ECE_JOINSTATUS) == HA_FAIL)) {
 		LOG_SERIOUS("Cannot respond to a join message\n");
 	} else {
@@ -963,7 +967,7 @@ fill_and_deliver_ece_msg(const char *orig,
 	ecemsg->corrolator = atoi(corr_str);
 
 	ecemsg->cmd = atoi(cmd_str);
-	
+
 	len    = strlen(data_str);
 	outbytes   = B64_maxbytelen(len);
 	data = 	(void *)g_malloc0(outbytes);
@@ -991,7 +995,7 @@ deliver_memb(memb_event_t *eventdata)
 	ece_event_t *ece_ev;
 
 	const oc_ev_membership_t *oc   = eventdata->oc;
-	
+
 	gboolean quorum = eventdata->quorum;
 
 	LOG_ENTRY();
@@ -1010,7 +1014,7 @@ deliver_memb(memb_event_t *eventdata)
 }
 
 
-/*  		END OF FUNCTIONS 				
+/*  		END OF FUNCTIONS
  * that distribute the membership events to the registered
  * clients instances
  */
@@ -1119,7 +1123,11 @@ hb_unregister(void)
 	int ret;
 	LOG_ENTRY();
 	llm_cleanup();
+#if (LLC_PROTOCOL_VERSION <= 1)
 	ret = gl_hb_handle->llc_ops->signoff(gl_hb_handle);
+#else
+	ret = gl_hb_handle->llc_ops->signoff(gl_hb_handle, TRUE);
+#endif
 	gl_hb_handle = NULL;
 	LOG_EXIT_INT(ret);
 	return ret;
@@ -1136,12 +1144,13 @@ hb_register(void)
 {
 	const char *node;
 	const char *hname;
+	int status;
 #ifdef HA_USE_IPC
 	IPC_Channel * hb_ch = NULL;
 #else
 	int           hb_fd = -1;
 #endif
-	
+
 	/* register with heartbeat, if failed return
 	 * -1
 	 */
@@ -1149,18 +1158,25 @@ hb_register(void)
 	gl_hb_handle = ll_cluster_new("heartbeat");
 
 	if(!gl_hb_handle) {
+		LOG_SERIOUS("Unable to access heartbeat cluster.\n");
 		goto exit;
 	}
 
-	if (gl_hb_handle->llc_ops->signon(gl_hb_handle, "evms")!= HA_OK) {
+	status = gl_hb_handle->llc_ops->signon(gl_hb_handle, "evms");
+	if (status != HA_OK) {
+		LOG_SERIOUS("Heartbeat llc_ops->signon() failed with status %d.\n", status);
+		goto exit;
+	}
+
+	hname = gl_hb_handle->llc_ops->get_mynodeid(gl_hb_handle);
+	if(hname == NULL) {
+		LOG_SERIOUS("Could not get my node name.  llc_ops->get_mynodeid() returned NULL.\n");
 		goto signoff;
 	}
 
-	if((hname = gl_hb_handle->llc_ops->get_mynodeid(gl_hb_handle)) == NULL) {
-		goto signoff;
-	}
-
-        if (gl_hb_handle->llc_ops->init_nodewalk(gl_hb_handle) != HA_OK) {
+        status = gl_hb_handle->llc_ops->init_nodewalk(gl_hb_handle);
+	if (status != HA_OK) {
+		LOG_SERIOUS("Failed to initialize for a node walk.  llc_ops->init_nodewalk() failed with status %d.\n", status);
 		goto signoff;
 	}
 	llm_init();
@@ -1180,7 +1196,9 @@ hb_register(void)
 		llm_add(node,strlen(node));
 	}
 	llm_end(hname);
-        if (gl_hb_handle->llc_ops->end_nodewalk(gl_hb_handle) != HA_OK) {
+        status = gl_hb_handle->llc_ops->end_nodewalk(gl_hb_handle);
+	if (status != HA_OK) {
+		LOG_SERIOUS("Failed to end node walk.  llc_ops->end_nodewalk() failed with status %d.\n", status);
 		goto signoff;
 	}
 
@@ -1196,7 +1214,11 @@ signoff:
 #else
 	if (hb_fd == -1) {
 #endif
+#if (LLC_PROTOCOL_VERSION <= 1)
 		gl_hb_handle->llc_ops->signoff(gl_hb_handle);
+#else
+		gl_hb_handle->llc_ops->signoff(gl_hb_handle, TRUE);
+#endif
 		llm_cleanup();
 	}
 exit:
@@ -1249,7 +1271,8 @@ handle_msg(struct ha_msg *h_msg)
 	}
 
 	/* a new daemon has joined/left the cluster */
-	if(strcmp(type, T_APICLISTAT)==0) {
+	if((strcmp(type, T_APICLISTAT)==0) ||
+	   (strcmp(type, ECE_CLIENTSTAT)==0)) {
 		const char *orig = ha_msg_value(h_msg, F_ORIG);
 		const char *status = ha_msg_value(h_msg, F_STATUS);
 		str = msg2string(h_msg);
@@ -2017,6 +2040,25 @@ ece_init( engine_functions_t *func)
 
 	mode = (func->get_engine_mode()==ENGINE_DAEMON)? MASTER: SLAVE;
 
+#ifdef MUST_HAVE_GLIB2
+	if(glib_major_version < 2) {
+		MESSAGE("The %d.%d.%d version of heartbeat that is installed "
+			"requires the %s plug-in to be linked with the GLIB version 2 "
+			"library.  "
+			"The plug-in is currently linking with GLIB version %d.%d.%d  "
+			"The plug-in cannot work with this version of GLIB.  "
+			"You will not be able to perform cluster management activites "
+			"such as managing shared storage and remote administration.  "
+			"This is most likely because you are running "
+			"the EVMS GUI which links with GLIB version 1.  "
+			"If so, try using the EVMS ncurses interface, evmsn.\n",
+			HA_MAJOR, HA_MINOR, HA_PATCH,
+			EVMS_HA_PLUGIN_LONG_NAME,
+			glib_major_version, glib_minor_version, glib_micro_version);
+		LOG_EXIT_INT(ELIBACC);
+		return ELIBACC;
+	}
+#endif
 	global_init(mode);
 
 	// if called with SLAVE mode, register with the MASTER's ece.
@@ -2034,7 +2076,7 @@ ece_init( engine_functions_t *func)
 				return ENODEV;
 			}
 
-			if(GLIB_CHECK_VERSION(2,0,0)) {
+			if(glib_major_version >= 2) {
 				GCHSource	*mstSource;
 				mstSource = G_main_add_IPC_Channel(
 					G_PRIORITY_LOW, sm_ch, FALSE,
@@ -2432,9 +2474,7 @@ static cluster_functions_t ft={
 
 plugin_record_t ece_plugin_record = {
 
-	id:			SetPluginID(EVMS_OEM_IBM,
-				EVMS_CLUSTER_MANAGER_INTERFACE_MODULE,
-				1),
+	id:			EVMS_HA_PLUGIN_ID,
 
 	version:		{major:      MAJOR_VERSION,
 				minor:      MINOR_VERSION,
@@ -2448,9 +2488,9 @@ plugin_record_t ece_plugin_record = {
 					minor:      0,
 					patchlevel: 0} },
 
-	short_name:		"Linux-HA",
-	long_name:		"Linux-HA Cluster Manager",
-	oem_name:		"IBM",
+	short_name:		EVMS_HA_PLUGIN_SHORT_NAME,
+	long_name:		EVMS_HA_PLUGIN_LONG_NAME,
+	oem_name:		EVMS_IBM_OEM_NAME,
 
 	functions:	{cluster:   &ft},
 
