@@ -2633,9 +2633,7 @@ static container_functions_t lvm_container_functions = {
 };
 
 plugin_record_t LVM_Plugin = {
-	.id = SetPluginID(EVMS_OEM_IBM,
-			  EVMS_REGION_MANAGER,
-			  0x01),
+	.id = EVMS_LVM_PLUGIN_ID,
 	.version = {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -2658,9 +2656,9 @@ plugin_record_t LVM_Plugin = {
 		.minor		= 1,
 		.patchlevel	= 0
 	},
-	.short_name = "LvmRegMgr",
-	.long_name = "LVM Region Manager",
-	.oem_name = "IBM",
+	.short_name = EVMS_LVM_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_LVM_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.plugin = &lvm_functions
 	},
