@@ -470,9 +470,21 @@ static int check_pv_size_prompt(storage_object_t *object,
 		   "If this is the case, then object %s is most likely NOT one "
 		   "of the LVM2 PVs.\n\n"
 
-		   "You may disable this message in the future by editing the "
-		   "EVMS config file and setting the device_size_prompt option "
-		   "to \"no\" in the lvm2 section."),
+		   "Choosing \"no\" here is the default, and is always safe, "
+		   "since no changes will be made to your configuration. "
+		   "Choosing \"yes\" will modify your configuration, and will "
+		   "cause problems if it's not the correct choice. The only "
+		   "time you would really need to choose \"yes\" here is if "
+		   "you are converting an existing container from using the "
+		   "LVM2 tools to using EVMS, and the container is NOT created "
+		   "from an MD RAID region. If you created and manage your "
+		   "containers only with EVMS, you should always be able to "
+		   "answer \"no\".\n\n"
+
+		   "If you answer \"no\" and your volumes are correctly "
+		   "discovered and activated, you may disable this message in "
+		   "the future by editing the EVMS config file and setting the "
+		   "device_size_prompt option to \"no\" in the lvm2 section."),
 		 object->name, size1, size2, object->name, object->name);
 	if (!answer) {
 		rc = EINVAL;
