@@ -37,7 +37,7 @@
 
 #define my_plugin_record my_plugin
 
-/* 
+/*
  * md_check_for_saved_info
  *
  *	This function is used during discovery.  It's called after we know that
@@ -94,7 +94,7 @@ out:
 
 
 /* Function: md_find_volume_for_object
- * 
+ *
  * The input object has been validated as MD member object.  Find the MD volume
  * set that this object belongs to.  If this is the first object, create a new
  * MD volume structure.
@@ -250,6 +250,8 @@ boolean md_check_for_expand_shrink_in_progress(md_volume_t *vol, md_member_t **m
 	list_element_t iter;
 	md_saved_info_t *saved_info;
 
+	LOG_ENTRY();
+
 	LIST_FOR_EACH(vol->members, iter, my_member) {
 		saved_info = my_member->saved_info;
 		if (saved_info) {
@@ -262,10 +264,12 @@ boolean md_check_for_expand_shrink_in_progress(md_volume_t *vol, md_member_t **m
 					vol->name,
 					saved_info->sector_mark);
 				*member = my_member;
+				LOG_EXIT_BOOL(TRUE);
 				return TRUE;
 			}
 		}
 	}
+	LOG_EXIT_BOOL(FALSE);
 	return FALSE;
 }
 
@@ -438,6 +442,12 @@ void md_analyze_volume(md_volume_t *vol)
 
 	LOG_ENTRY();
 
+	if (!vol->region) {
+		LOG_ERROR("No region for %s.\n", vol->name);
+		LOG_EXIT_VOID();
+		return;
+	}
+
 	if (vol->flags & MD_NEW_REGION) {
 		LOG_DEBUG("%s is a new region, skip analyzing superblock.\n", vol->name);
 		goto out;
@@ -506,10 +516,10 @@ void md_analyze_volume(md_volume_t *vol)
 		}
 	}
 
-	vol->sb_func->analyze_sb(vol);
+	vol->sb_func->analyze_sb(vol);	
 
 out:
-	if ((vol->flags & MD_CORRUPT) && vol->region) {
+	if (vol->flags & MD_CORRUPT) {
 		vol->region->flags |= SOFLAG_CORRUPT;
 	}
 	LOG_EXIT_VOID();
@@ -650,7 +660,7 @@ int md_analyze_active_region(md_volume_t *vol)
 							 _("%s region %s is corrupt."
 							   "  The number of raid disks for a full functional array is %d."
 							   "  The number of active disks is %d."),
-							 level_to_string(md_info.level), vol->name, 
+							 level_to_string(md_info.level), vol->name,
 							 md_info.raid_disks, md_info.active_disks);
 					vol->flags |= MD_CORRUPT;
 					goto queue_corrupt_message;
@@ -661,7 +671,7 @@ int md_analyze_active_region(md_volume_t *vol)
 						 _("%s region %s is corrupt."
 						   "  The number of raid disks for a full functional array is %d."
 						   "  The number of active disks is %d.\n"),
-						 level_to_string(md_info.level), vol->name, 
+						 level_to_string(md_info.level), vol->name,
 						 md_info.raid_disks, md_info.active_disks);
 				vol->flags |= MD_CORRUPT;
 				goto queue_corrupt_message;
@@ -748,7 +758,7 @@ int md_analyze_active_region(md_volume_t *vol)
 						  "  The Kernel MD driver still has a reference to this disk."
 						  "  However, EVMS did not find MD superblock on this disk.\n\n"
 						  "  Would you like to request the kernel to release the reference to this disk?\n"),
-						level_to_string(md_info.level), vol->name, 
+						level_to_string(md_info.level), vol->name,
 						d.major, d.minor);
 			
 				if (md_get_yes_no_response(message_buffer) == TRUE) {
@@ -772,7 +782,7 @@ int md_analyze_active_region(md_volume_t *vol)
 queue_corrupt_message:
 	if (vol->flags & MD_CORRUPT) {
 		if (length > 0) {
-			md_queue_corrupt_message(vol->personality, message_buffer, length);
+			md_queue_corrupt_message(vol, message_buffer, length);
 		}
 		rc = EINVAL;
 	}
