@@ -292,6 +292,8 @@ static int set_disk_info(md_disk_info_t *info, extended_info_t *cur_info)
 	int info_count = 0;
 	char buf[64];
 
+	LOG_ENTRY();
+
 	sprintf(buf, "number %d", info->number);
 	cur_info->name = EngFncs->engine_strdup(buf);
 	cur_info->title = EngFncs->engine_strdup(_("Number"));
@@ -375,6 +377,7 @@ static int set_disk_info(md_disk_info_t *info, extended_info_t *cur_info)
 	if (info_count != NUM_DISK_INFO_ENTRIES) {
 		LOG_MD_BUG();
 	}
+	LOG_EXIT_INT(info_count);
 	return info_count;
 }
 
@@ -383,6 +386,9 @@ static int get_superblock_disk_info(md_volume_t *vol, int index, extended_info_t
 	mdu_disk_info_t d;
 	md_disk_info_t info;
 	char buffer[256];
+	int rc;
+
+	LOG_ENTRY();
 
 	d.number = index;
 	vol->sb_func->get_sb_disk_info_for_index(vol->sb, &d);
@@ -423,13 +429,19 @@ static int get_superblock_disk_info(md_volume_t *vol, int index, extended_info_t
 
 	info.state = buffer;
 
-	return set_disk_info(&info, cur_info);
+	rc = set_disk_info(&info, cur_info);
+
+	LOG_EXIT_INT(rc);
+	return rc;
 }
 
 static int get_member_disk_info(md_member_t *member, extended_info_t *cur_info)
 {
 	md_disk_info_t info;
 	char buffer[256];
+	int rc;
+
+	LOG_ENTRY();
 
 	info.number = member->dev_number;
 	if (member->obj && member->obj->dev_major) {
@@ -471,7 +483,10 @@ static int get_member_disk_info(md_member_t *member, extended_info_t *cur_info)
 	}
 	info.state = buffer;
 	
-	return set_disk_info(&info, cur_info);
+	rc = set_disk_info(&info, cur_info);
+
+	LOG_EXIT_INT(rc);
+	return rc;
 }
 
 static int md_get_child_disk_info(md_member_t *member, extended_info_array_t ** info_array)
@@ -492,6 +507,7 @@ static int md_get_child_disk_info(md_member_t *member, extended_info_array_t **
 		if (info->count != NUM_DISK_INFO_ENTRIES) {
 			LOG_MD_BUG();
 			EngFncs->engine_free(info);
+			LOG_EXIT_INT(EINVAL);
 			return EINVAL;
 		}
 
@@ -540,6 +556,7 @@ static int md_get_stale_disk_info(md_member_t *member, extended_info_array_t **
 		if (info->count != NUM_DISK_INFO_ENTRIES) {
 			LOG_MD_BUG();
 			EngFncs->engine_free(info);
+			LOG_EXIT_INT(EINVAL);
 			return EINVAL;
 		}
 
@@ -599,7 +616,7 @@ static int md_get_superblock_info(
 
 	info_entries = NUM_SUPER_INFO_ENTRIES + super.nr_disks*NUM_DISK_INFO_ENTRIES;
 	
-	info = EngFncs->engine_alloc(sizeof(extended_info_array_t) + 
+	info = EngFncs->engine_alloc(sizeof(extended_info_array_t) +
 				     sizeof(extended_info_t) * info_entries);
 	if (info == NULL) {
 		LOG_CRITICAL("Error getting memory for an extended_info_array.\n");
