@@ -308,7 +308,7 @@ int md_replace_child(storage_object_t *region,
 	child_size = md_object_usable_size(child, &vol->sb_ver, vol->chunksize);
 	new_child_size = md_object_usable_size(new_child, &vol->sb_ver, vol->chunksize);
 
-	LOG_DEBUG("region: %s, CHILD: %s, NEW CHILD: %s\n", 
+	LOG_DEBUG("region: %s, CHILD: %s, NEW CHILD: %s\n",
 		  region->name, child->name, new_child->name);
 	LOG_DEBUG(" CHILD object size=%"PRIu64", MD size=%"PRIu64""
 		  " and NEW CHILD: object size=%"PRIu64", MD size=%"PRIu64"\n",
@@ -526,6 +526,8 @@ boolean md_is_region_active(storage_object_t * region)
 	int rc = 1;
 	mdu_array_info_t info;
 
+	LOG_ENTRY();
+
 	if ((region->plugin == linear_plugin) ||
 	    (region->plugin == raid0_plugin)) {
 		rc = EngFncs->dm_update_status(region);
@@ -535,7 +537,10 @@ boolean md_is_region_active(storage_object_t * region)
 		md_get_kernel_info(region, &info);
 	}
 
-	return (region->flags & SOFLAG_ACTIVE) ? TRUE : FALSE;
+	rc = (region->flags & SOFLAG_ACTIVE) ? TRUE : FALSE;
+
+	LOG_EXIT_BOOL(rc);
+	return rc;
 }
 
 
@@ -744,9 +749,12 @@ int find_disk_in_active_region(storage_object_t *region, int major, int minor)
 	md_volume_t *vol;
 	mdu_disk_info_t info;
 
+	LOG_ENTRY();
+
 	vol = (md_volume_t *)region->private_data;
 	if (!vol || !vol->sb_func) {
 		LOG_MD_BUG();
+		LOG_EXIT_INT(-1);
 		return -1;
 	}
 
@@ -762,6 +770,8 @@ int find_disk_in_active_region(storage_object_t *region, int major, int minor)
 			major, minor, region->name);
 		index = -1;
 	}
+
+	LOG_EXIT_INT(index);
 	return index;
 }
 
@@ -781,7 +791,7 @@ md_member_t *md_find_member(int major, int minor)
 	for (vol = volume_list_head; vol; vol = vol->next) {
 		LIST_FOR_EACH(vol->members, iter, member) {
 			if ((member->obj) &&
-			    (member->obj->dev_major = major) && 
+			    (member->obj->dev_major = major) &&
 			    (member->obj->dev_minor == minor)) {
 				LOG_EXIT_PTR(member);
 				return member;
@@ -822,7 +832,7 @@ md_member_t * md_volume_find_member_from_major_minor(md_volume_t *vol, int major
 
 	LOG_ENTRY();
 	LIST_FOR_EACH(vol->members, iter, member) {
-		if ((member->obj->dev_major == major) && 
+		if ((member->obj->dev_major == major) &&
 		    (member->obj->dev_minor == minor)) {
 			LOG_EXIT_PTR(member);
 			return member;
@@ -991,6 +1001,7 @@ void md_free_member(md_member_t *member)
 {
 	LOG_ENTRY();
 	if (!member) {
+		LOG_EXIT_VOID();
 		return;
 	}
 
@@ -1135,9 +1146,9 @@ md_member_t * md_clone_member( md_member_t *org)
 				goto out;
 			}
 			if (org->saved_info) {
-				new_member->saved_info = EngFncs->engine_alloc(sizeof(*(org->saved_info)));
+				new_member->saved_info = EngFncs->engine_alloc(MD_SAVED_INFO_BYTES);
 				if (new_member->saved_info) {
-					*(new_member->saved_info) = *(org->saved_info);
+					memcpy(new_member->saved_info, org->saved_info, MD_SAVED_INFO_BYTES);
 				} else {
 					rc = ENOMEM;
 					goto out;
@@ -1173,6 +1184,7 @@ md_volume_t * md_clone_volume( md_volume_t *org)
 	new_vol = md_allocate_volume();
 	if (new_vol) {
 		*new_vol = *org;
+		new_vol->private_data = NULL;
 		new_vol->nr_disks = 0;
 		new_vol->members = EngFncs->allocate_list();
 		new_vol->setup_funcs = EngFncs->allocate_list();
@@ -1916,6 +1928,8 @@ int md_volume_remove_faulty_from_inactive_region(md_volume_t *vol, storage_objec
 	int rc=0;
 	md_member_t *member;
 
+	LOG_ENTRY();
+
 	member = md_volume_find_object(vol, faulty);
 	if (!member) {
 		LOG_WARNING("%s is not in region %s.\n", faulty->name, vol->name);
