@@ -70,6 +70,8 @@ static u_int32_t cpy_str(char *target, u_int32_t target_size, char *src)
 static void md_analyze_sb(md_volume_t *vol, int level, int raid_disks, u_int32_t chunksize_in_bytes)
 {
 	int length=0;
+	int count;
+
 	LOG_ENTRY();
 
 	//Found more active disks than actual raid_disks ?	
@@ -106,7 +108,7 @@ static void md_analyze_sb(md_volume_t *vol, int level, int raid_disks, u_int32_t
 							 _("%s region %s is corrupt."
 							   "  The number of raid disks for a full functional array is %d."
 							   "  The number of active disks is %d."),
-							 level_to_string(level), vol->name, 
+							 level_to_string(level), vol->name,
 							 raid_disks, vol->active_disks);
 					vol->flags |= MD_CORRUPT;
 					goto queue_corrupt_message;
@@ -117,7 +119,7 @@ static void md_analyze_sb(md_volume_t *vol, int level, int raid_disks, u_int32_t
 						 _("%s region %s is corrupt."
 						   "  The number of raid disks for a full functional array is %d."
 						   "  The number of active disks is %d.\n"),
-						 level_to_string(level), vol->name, 
+						 level_to_string(level), vol->name,
 						 raid_disks, vol->active_disks);
 				vol->flags |= MD_CORRUPT;
 				goto queue_corrupt_message;
@@ -125,7 +127,7 @@ static void md_analyze_sb(md_volume_t *vol, int level, int raid_disks, u_int32_t
 	}
 
 	if ((level == MD_LEVEL_RAID0) ||
-	    (level == MD_LEVEL_RAID4) || 
+	    (level == MD_LEVEL_RAID4) ||
 	    (level == MD_LEVEL_RAID5) ) {
 		if (!chunksize_in_bytes) {
 			length = sprintf(message_buffer,
@@ -166,16 +168,29 @@ static void md_analyze_sb(md_volume_t *vol, int level, int raid_disks, u_int32_t
 	}
 
 queue_corrupt_message:
-	if (vol->flags & MD_CORRUPT) {
-		md_queue_corrupt_message(level_to_pers(level), message_buffer, length);
+	if ((vol->flags & MD_CORRUPT) && (length > 0)) {
+		/*
+		 * We don't want to confuse the user with many corrupt messages
+		 * for the same volume.
+		 */
+		count = md_count_corrupt_messages(vol);
+		if (count == 0) {
+			md_queue_corrupt_message(vol, message_buffer, length);
+		} else {
+			LOG_WARNING("Number of corrupt message had been queued for %s: %d.\n",
+				    vol->name, count);
+		}
 	}
 	LOG_EXIT_VOID();
 }
 
-static u_int32_t get_random(void) {
+static u_int32_t get_random(void)
+{
 	u_int32_t num;
 	int fd;
 
+	LOG_ENTRY();
+
 	fd = open("/dev/urandom", O_RDONLY);
 	if (fd != -1 && read(fd, &num, 4) == 4) {
 		LOG_DEBUG("raid set magic: %x\n", num);
@@ -185,6 +200,8 @@ static u_int32_t get_random(void) {
 		LOG_DEBUG("raid set magic (pseudo-random): %x\n", num);
 	}
 	close(fd);
+
+	LOG_EXIT_INT(num);
 	return num;
 }
 
@@ -201,6 +218,8 @@ static unsigned int md_calc_saved_info_csum(md_saved_info_t *info)
 	int size = sizeof(*info) + (info->expand_shrink_cnt)*2;
 	unsigned int *isuper = (unsigned int*)info;
 
+	LOG_ENTRY();
+
 	disk_csum = info->csum;
 	info->csum = 0;
 	newcsum = 0;
@@ -212,6 +231,8 @@ static unsigned int md_calc_saved_info_csum(md_saved_info_t *info)
 
 	csum = (newcsum & 0xffffffff) + (newcsum >> 32);
 	info->csum = disk_csum;
+
+	LOG_EXIT_INT(csum);
 	return csum;
 }
 
@@ -231,6 +252,8 @@ static void sb0_get_sb_disk_info_for_index(void *super, mdu_disk_info_t *info)
 {
 	mdp_super_t *sb = (mdp_super_t *)super;
 
+	LOG_ENTRY();
+
 	if (info->number < MD_SB_DISKS) {
 		mdp_disk_t *d = &sb->disks[info->number];
 
@@ -242,6 +265,8 @@ static void sb0_get_sb_disk_info_for_index(void *super, mdu_disk_info_t *info)
 		LOG_MD_BUG();
 		memset(info, 0, sizeof(*info));
 	}
+
+	LOG_EXIT_VOID();
 }
 
 static md_array_info_t * sb0_get_disk_array_info(void *super)
@@ -281,6 +306,8 @@ static void sb0_get_sb_info(void *super, md_super_info_t *info)
 {
 	mdp_super_t *sb = (mdp_super_t *)super;
 
+	LOG_ENTRY();
+
 	memset(info, 0, sizeof(*info));
 
 	info->md_magic = sb->md_magic;
@@ -317,6 +344,8 @@ static void sb0_get_sb_info(void *super, md_super_info_t *info)
 	info->events += sb->events_lo;
 	info->chunksize = sb->chunk_size >> EVMS_VSECTOR_SIZE_SHIFT;           /* in sectors */
 	info->this_disk_index = sb->this_disk.number;
+
+	LOG_EXIT_VOID();
 }
 
 /*
@@ -360,7 +389,7 @@ static u_int64_t sb0_calc_volume_size(md_volume_t *vol)
 		LIST_FOR_EACH(vol->members, iter, member) {
 			smallest_size = min(smallest_size, member->data_size);
 			member->data_offset = 0; //just to make sure
-			member->super_offset = MD_NEW_SIZE_SECTORS(member->obj->size); 
+			member->super_offset = MD_NEW_SIZE_SECTORS(member->obj->size);
 		}
 		sb->size = smallest_size / 2;
 	}
@@ -462,12 +491,16 @@ static int sb0_calc_sb_csum(mdp_super_t *super)
 	unsigned long csum;
 	int i;
 	unsigned int *superc = (int*) super;
-	super->sb_csum = 0;
 
+	LOG_ENTRY();
+
+	super->sb_csum = 0;
 	for (i=0; i<MD_SB_BYTES/4; i++)
 		newcsum+= superc[i];
 	csum = (newcsum& 0xffffffff) + (newcsum>>32);
 	super->sb_csum = oldcsum;
+
+	LOG_EXIT_INT((int)csum);
 	return csum;
 }
 
@@ -607,7 +640,7 @@ static int sb0_add_new_disk(md_member_t *member)
 		member->data_size = md_object_usable_size(member->obj,
 							  &member->vol->sb_ver,
 							  member->vol->chunksize);
-		LOG_DEBUG("Data size of %s is set to %"PRIu64" sectors.\n", 
+		LOG_DEBUG("Data size of %s is set to %"PRIu64" sectors.\n",
 			  member->obj->name, member->data_size);
 	}
 out:
@@ -850,7 +883,7 @@ static void sb0_load_this_device_info(md_member_t *member)
 	case 4:
 	case 5:
 		member->data_size = MD_CHUNK_ALIGN_NEW_SIZE_SECTORS(
-			(sb->chunk_size >> EVMS_VSECTOR_SIZE_SHIFT), 
+			(sb->chunk_size >> EVMS_VSECTOR_SIZE_SHIFT),
 			member->obj->size);
 		break;
 	case 1:
@@ -946,8 +979,7 @@ static int sb0_analyze_sb(md_volume_t *vol)
 	LOG_ENTRY();
 
 	if (vol->flags & MD_CORRUPT) {
-		LOG_WARNING("%s has been set CORRUPT, skip analyzing...\n", vol->name);
-		goto out;
+		LOG_WARNING("%s has been set CORRUPT!\n", vol->name);
 	}
 
 	nr_disks = md_volume_count_children(vol);
@@ -990,7 +1022,6 @@ static int sb0_analyze_sb(md_volume_t *vol)
 		LOG_WARNING("MD region %s is degraded\n", vol->name);
 	}
 
-out:
 	LOG_EXIT_INT(vol->flags);
 	return vol->flags;
 }
@@ -1252,14 +1283,19 @@ static int sb0_zero_superblock(md_member_t *member, boolean now)
 {
 	mdp_super_t sb;
 
+	LOG_ENTRY();
+
 	if (now == TRUE) {
 		memset(&sb, 0, MD_SB_BYTES);
 		if ( WRITE(member->obj, member->super_offset, MD_SB_SECTORS, (char*)&sb)) {
+			LOG_EXIT_INT(EIO);
 			return EIO;
 		}
 	} else {
 		KILL_SECTORS(member->obj, member->super_offset, MD_SB_SECTORS);
 	}
+
+	LOG_EXIT_INT(0);
 	return 0;
 }
 
@@ -1268,17 +1304,22 @@ static int sb0_zero_saved_info(md_member_t *member, boolean now)
 	md_saved_info_t info;
 	u_int64_t location;
 
+	LOG_ENTRY();
+
 	location = MD_NEW_SIZE_SECTORS(member->obj->size);
 	location += MD_SB0_SAVED_INFO_SECTOR_OFFSET;
 
 	if (now == TRUE) {
 		memset(&info, 0, sizeof(md_saved_info_t));
 		if ( WRITE(member->obj, location, MD_SAVED_INFO_SECTS, (char*)&info)) {
+			LOG_EXIT_INT(EIO);
 			return EIO;
 		}
 	} else {
 		KILL_SECTORS(member->obj, location, MD_SAVED_INFO_SECTS);
 	}
+
+	LOG_EXIT_INT(0);
 	return 0;
 }
 
@@ -1330,6 +1371,9 @@ static struct super_func sb0_handler = {
 static u_int64_t sb1_minor_version_to_super_offset(storage_object_t *obj, int minor_version)
 {
 	u_int64_t loc = 0;
+
+	LOG_ENTRY();
+
 	switch(minor_version) {
 	case 0:
 		loc = obj->size;
@@ -1343,12 +1387,17 @@ static u_int64_t sb1_minor_version_to_super_offset(storage_object_t *obj, int mi
 		loc = 4*2;
 		break;
 	}
+
+	LOG_EXIT_U64(loc);
 	return loc;
 }
 
 static u_int64_t sb1_minor_version_to_data_offset(storage_object_t *obj, int minor_version)
 {
 	u_int64_t offset;
+
+	LOG_ENTRY();
+
 	switch(minor_version) {
 	case 0:
 		offset = 0;
@@ -1363,6 +1412,8 @@ static u_int64_t sb1_minor_version_to_data_offset(storage_object_t *obj, int min
 		LOG_MD_BUG();
 		return -1;
 	}
+
+	LOG_EXIT_U64(offset);
 	return offset;
 }
 
@@ -1371,6 +1422,8 @@ static int sb1_super_offset_to_minor_version(storage_object_t *obj, u_int64_t su
 	u_int64_t loc = 0;
 	int minor_version;
 
+	LOG_ENTRY();
+
 	for (minor_version=0; minor_version <=2; minor_version++) {
 		switch(minor_version) {
 		case 0:
@@ -1386,9 +1439,11 @@ static int sb1_super_offset_to_minor_version(storage_object_t *obj, u_int64_t su
 			break;
 		}
 		if (loc == super_offset) {
+			LOG_EXIT_INT(minor_version);
 			return minor_version;
 		}
 	}
+	LOG_EXIT_INT(-1);
 	return -1;
 }
 
@@ -1401,6 +1456,7 @@ static void sb1_disk_to_cpu(mdp_sb_1_t * sb)
 {
 	int i;
 
+	LOG_ENTRY();
 	sb->magic =                DISK_TO_CPU32(sb->magic);
 	sb->major_version =        DISK_TO_CPU32(sb->major_version);
 	sb->feature_map =          DISK_TO_CPU32(sb->feature_map);
@@ -1424,19 +1480,21 @@ static void sb1_disk_to_cpu(mdp_sb_1_t * sb)
 	for (i=0; i<sb->max_dev; i++) {
 		sb->dev_roles[i] = DISK_TO_CPU16(sb->dev_roles[i]);
 	}
+	LOG_EXIT_VOID();
 }
 
 /*
- * Convert a MD superblock 1 in CPU endian format to 
+ * Convert a MD superblock 1 in CPU endian format to
  * disk endian (little endian) format.
  *
- * Note: To keep a copy of MD superblock in CPU format, 
+ * Note: To keep a copy of MD superblock in CPU format,
  * duplicate it before calling this function.
  */
 static void sb1_cpu_to_disk(mdp_sb_1_t * sb)
 {
 	int i;
 
+	LOG_ENTRY();
 	sb->magic =                CPU_TO_DISK32(sb->magic);
 	sb->major_version =        CPU_TO_DISK32(sb->major_version);
 	sb->feature_map =          CPU_TO_DISK32(sb->feature_map);
@@ -1461,6 +1519,7 @@ static void sb1_cpu_to_disk(mdp_sb_1_t * sb)
 		sb->dev_roles[i] = CPU_TO_DISK16(sb->dev_roles[i]);
 	}
 	sb->max_dev =              CPU_TO_DISK32(sb->max_dev);
+	LOG_EXIT_VOID();
 }
 
 
@@ -1468,6 +1527,7 @@ static void sb1_print_sb(void *super)
 {
 	mdp_sb_1_t *sb = (mdp_sb_1_t *)super;
 	int i;
+	LOG_ENTRY();
 	LOG_DEBUG("Sizeof structure: %d bytes.\n", sizeof(*sb));
 	LOG_DEBUG("magic:           %x.\n", sb->magic);
 	LOG_DEBUG("major_version:   %d.\n", sb->major_version);
@@ -1490,6 +1550,7 @@ static void sb1_print_sb(void *super)
 	for (i=0; i<sb->max_dev; i++) {
 		LOG_DEBUG("dev_roles[%03d]:  %X,\n", i, sb->dev_roles[i]);
 	}
+	LOG_EXIT_VOID();
 }
 
 /*
@@ -1505,6 +1566,8 @@ static unsigned int sb1_calc_sb_csum(mdp_sb_1_t * sb)
 	int size = sizeof(*sb) + (sb->max_dev)*2;
 	unsigned int *isuper = (unsigned int*)sb;
 
+	LOG_ENTRY();
+
 	disk_csum = sb->sb_csum;
 	sb->sb_csum = 0;
 	newcsum = 0;
@@ -1516,6 +1579,8 @@ static unsigned int sb1_calc_sb_csum(mdp_sb_1_t * sb)
 
 	csum = (newcsum & 0xffffffff) + (newcsum >> 32);
 	sb->sb_csum = disk_csum;
+
+	LOG_EXIT_INT(csum);
 	return csum;
 }
 
@@ -1545,11 +1610,13 @@ static void *sb1_allocate_sb(void)
 
 static int sb1_duplicate_sb(void **target, void *src)
 {
+	LOG_ENTRY();
 	*target = EngFncs->engine_alloc(MD_SB_1_BYTES);
 	if (!*target) {
 		return ENOMEM;
 	}
 	memcpy(*target, src, MD_SB_1_BYTES);
+	LOG_EXIT_INT(0);
 	return 0;
 }
 
@@ -1637,7 +1704,7 @@ static int sb1_add_new_disk(md_member_t *member)
 	sb->dev_number = member->dev_number;
 
 	if (member->data_size == -1) {
-		sb->data_size = md_object_usable_size(member->obj, 
+		sb->data_size = md_object_usable_size(member->obj,
 						      &member->vol->sb_ver,
 						      member->vol->chunksize);
 		member->data_size = sb->data_size;
@@ -1646,7 +1713,7 @@ static int sb1_add_new_disk(md_member_t *member)
 	}
 
 	if (member->data_offset == -1) {
-		sb->data_offset = sb1_minor_version_to_data_offset(member->obj, 
+		sb->data_offset = sb1_minor_version_to_data_offset(member->obj,
 								   member->vol->sb_ver.minor_version);
 		member->data_offset = sb->data_offset;
 	} else {
@@ -1654,7 +1721,7 @@ static int sb1_add_new_disk(md_member_t *member)
 	}
 
 	if (member->super_offset == -1) {
-		sb->super_offset = sb1_minor_version_to_super_offset(member->obj, 
+		sb->super_offset = sb1_minor_version_to_super_offset(member->obj,
 								     member->vol->sb_ver.minor_version);
 		member->super_offset = sb->super_offset;
 	} else {
@@ -1688,7 +1755,7 @@ out:
 static int sb1_activate_spare(md_member_t *member)
 {
 	int rc = 0;
-	md_volume_t *vol; 
+	md_volume_t *vol;
 	mdp_sb_1_t *sb = NULL;
 
 	LOG_ENTRY();
@@ -1718,7 +1785,7 @@ out:
 static int sb1_remove_disk(md_member_t *member, boolean resize)
 {
 	int rc = 0;
-	md_volume_t *vol; 
+	md_volume_t *vol;
 	mdp_sb_1_t *sb = NULL;
 	md_member_t *my_member;
 	list_element_t iter;
@@ -1757,7 +1824,7 @@ static int sb1_remove_disk(md_member_t *member, boolean resize)
 		sb->raid_disks--;
 		sb->max_dev--;
 		LIST_FOR_EACH(vol->members, iter, my_member) {
-			if ((my_member != member) && 
+			if ((my_member != member) &&
 			    (my_member->raid_disk > member->raid_disk)) {
 				my_member->dev_number--;
 				my_member->raid_disk--;
@@ -2083,6 +2150,8 @@ static void sb1_get_sb_disk_info(md_member_t *member, mdu_disk_info_t *info)
 {
 	mdp_sb_1_t *sb = (mdp_sb_1_t *)member->sb;
 
+	LOG_ENTRY();
+
 	info->number = member->dev_number;
 	info->major = member->obj ? member->obj->dev_major : 0;
 	info->minor = member->obj ? member->obj->dev_minor : 0;
@@ -2100,12 +2169,16 @@ static void sb1_get_sb_disk_info(md_member_t *member, mdu_disk_info_t *info)
 		info->state |= (1<<MD_DISK_ACTIVE);
 		info->state |= (1<<MD_DISK_SYNC);
 	}
+
+	LOG_EXIT_VOID();
 }
 
 static void sb1_get_sb_disk_info_for_index(void *super, mdu_disk_info_t *info)
 {
 	mdp_sb_1_t *sb = (mdp_sb_1_t *)super;
 
+	LOG_ENTRY();
+
 	if (info->number < MD_SB_1_DISKS) {
 		info->major = 0;
 		info->minor = 0;
@@ -2127,6 +2200,8 @@ static void sb1_get_sb_disk_info_for_index(void *super, mdu_disk_info_t *info)
 		LOG_MD_BUG();
 		memset(info, 0, sizeof(*info));
 	}
+
+	LOG_EXIT_VOID();
 }
 
 static md_array_info_t * sb1_get_disk_array_info(void *super)
@@ -2178,6 +2253,8 @@ static void sb1_get_sb_info(void *super, md_super_info_t *info)
 	mdp_sb_1_t *sb = (mdp_sb_1_t *)super;
 	int i;
 
+	LOG_ENTRY();
+
 	memset(info, 0, sizeof(*info));
 
 	sb1_print_sb(sb);
@@ -2196,7 +2273,7 @@ static void sb1_get_sb_info(void *super, md_super_info_t *info)
 	}
 	info->patch_version = 0;
 	info->set_uuid0 = (u_int32_t)sb->set_uuid[0];
-	info->set_uuid1 = (u_int32_t)sb->set_uuid[4];  
+	info->set_uuid1 = (u_int32_t)sb->set_uuid[4];
 	info->set_uuid2 = (u_int32_t)sb->set_uuid[8];
 	info->set_uuid3 = (u_int32_t)sb->set_uuid[12];
 	info->ctime = (time_t)sb->ctime;
@@ -2224,6 +2301,8 @@ static void sb1_get_sb_info(void *super, md_super_info_t *info)
 	info->events = sb->events;
 	info->chunksize = sb->chunksize;
 	info->this_disk_index = sb->dev_number;
+
+	LOG_EXIT_VOID();
 }
 
 /*
@@ -2267,8 +2346,7 @@ static int sb1_analyze_sb(md_volume_t *vol)
 
 	LOG_ENTRY();
 	if (vol->flags & MD_CORRUPT) {
-		LOG_WARNING("%s has been set CORRUPT, skip analyzing...\n", vol->name);
-		goto out;
+		LOG_WARNING("%s has been set CORRUPT!\n", vol->name);
 	}
 
 	nr_disks = md_volume_count_children(vol);
@@ -2311,7 +2389,6 @@ static int sb1_analyze_sb(md_volume_t *vol)
 		LOG_WARNING("MD region %s is degraded\n", vol->name);
 	}
 
-out:
 	LOG_EXIT_INT(vol->flags);
 	return vol->flags;
 }
@@ -2473,6 +2550,7 @@ static int sb1_zero_superblock(md_member_t *member, boolean now)
 	if (now == TRUE) {
 		memset(&sb, 0, MD_SB_1_BYTES);
 		if ( WRITE(member->obj, member->super_offset, MD_SB_1_SECTORS, (char*)&sb)) {
+			LOG_EXIT_INT(EIO);
 			return EIO;
 		}
 	} else {
@@ -2487,6 +2565,8 @@ static int sb1_zero_saved_info(md_member_t *member, boolean now)
 	md_saved_info_t info;
 	u_int64_t location;
 
+	LOG_ENTRY();
+
 	location = member->super_offset;
 	location += MD_SB1_SAVED_INFO_SECTOR_OFFSET;
 	LOG_DEBUG("Removing MD saved info from %s at %"PRIu64".\n",
@@ -2495,11 +2575,14 @@ static int sb1_zero_saved_info(md_member_t *member, boolean now)
 	if (now == TRUE) {
 		memset(&info, 0, sizeof(md_saved_info_t));
 		if ( WRITE(member->obj, location, MD_SAVED_INFO_SECTS, (char*)&info)) {
+			LOG_EXIT_INT(EIO);
 			return EIO;
 		}
 	} else {
 		KILL_SECTORS(member->obj, location, MD_SAVED_INFO_SECTS);
 	}
+
+	LOG_EXIT_INT(0);
 	return 0;
 }
 
@@ -2917,11 +3000,14 @@ u_int64_t md_object_usable_size(storage_object_t *obj, md_sb_ver_t *sb_ver, u_in
 {
 	u_int64_t size;
 
+	LOG_ENTRY();
+
 	if (sb_ver->major_version == MD_SB_VER_0) {
 		size = MD_NEW_SIZE_SECTORS(obj->size);
 		if (chunksize) {
 			size = size & ~(chunksize-1);
 		}
+		LOG_EXIT_U64(size);
 		return size;
 	} else if (sb_ver->major_version == MD_SB_VER_1) {
 		size = obj->size;
@@ -2938,6 +3024,7 @@ u_int64_t md_object_usable_size(storage_object_t *obj, md_sb_ver_t *sb_ver, u_in
 			break;
 		default:
 			LOG_MD_BUG();
+			LOG_EXIT_INT(0);
 			return 0;
 		}
 		if (chunksize) {
@@ -2946,6 +3033,7 @@ u_int64_t md_object_usable_size(storage_object_t *obj, md_sb_ver_t *sb_ver, u_in
 		return size;
 	} else {
 		LOG_MD_BUG();
+		LOG_EXIT_INT(0);
 		return 0;
 	}
 }
@@ -2959,7 +3047,7 @@ void md_volume_set_name(md_volume_t *vol, const char *name)
 	}
 }
 
-/* 
+/*
  * md_read_metadata
  *
  * This function reads MD metadata (superblock, saved info)
