@@ -665,7 +665,7 @@ static int raid0_create_region(md_volume_t *vol, list_anchor_t output_list, bool
 			md_append_region_to_object(region, member->obj);
 		} else {
 			length = sprintf(message_buffer, _("  The disk indexed %d is missing.\n"), i);
-			md_queue_corrupt_message(vol->personality, message_buffer, length);
+			md_queue_corrupt_message(vol, message_buffer, length);
 			vol->flags |= MD_CORRUPT;
 		}
 	}
@@ -1093,7 +1093,7 @@ static int add_active_disk(md_volume_t *vol, storage_object_t *new_disk)
 		rc = EINVAL;
 		goto out;
 	}
-                                                                               
+
 	member = md_allocate_member(new_disk);
 	if (!member) {
 		rc = ENOMEM;
@@ -1815,8 +1815,8 @@ static int raid0_copy_data(
 
 	if (buf == NULL) {
 		*sectors = 0;
-		LOG_EXIT_INT(ENOMEM);
-		return ENOMEM;
+		rc = ENOMEM;
+		goto out;
 	}
 
 	transfer_sects = buf_size >> EVMS_VSECTOR_SIZE_SHIFT;
@@ -1840,8 +1840,9 @@ static int raid0_copy_data(
 			info = saved_member->saved_info;
 		} else {
 			LOG_ERROR("Can't keep track of copy progress.\n");
-			LOG_EXIT_INT(EINVAL);
-			return EINVAL;
+			*sectors = 0;
+			rc = EINVAL;
+			goto out;
 		}
 	}
 	
@@ -1902,10 +1903,13 @@ static int raid0_copy_data(
 		EngFncs->progress(&progress);
 	}
 
-	free(buf);
-
 	LOG_DEFAULT("Last LSN=%"PRIu64", used %"PRIu64"-sector blocks.\n", lsn, transfer_sects);
 
+out:
+	if (buf) {
+		free(buf);
+	}
+
 	LOG_EXIT_INT(rc);
 	return rc;
 }
@@ -1981,6 +1985,7 @@ static int raid0_do_expand(storage_object_t *region)
 	md_saved_info_t *info = NULL;
 	md_member_t *saved_member;
 	md_member_t *member;
+	char msg[256];
 
 	LOG_ENTRY();
 
@@ -2029,10 +2034,10 @@ static int raid0_do_expand(storage_object_t *region)
 
 	sectors = md_volume_calc_size(org_vol);
 	
-	sprintf(message_buffer, "Expanding RAID0 region %s...", region->name);
-	LOG_DEBUG("%s (sectors=%"PRIu64")\n",message_buffer, sectors);
+	sprintf(msg, "Expanding RAID0 region %s...", region->name);
+	LOG_DEBUG("%s (sectors=%"PRIu64")\n", msg, sectors);
 	
-	rc = raid0_copy_data(org_vol, volume, &sectors, TRUE, TRUE, message_buffer);
+	rc = raid0_copy_data(org_vol, volume, &sectors, TRUE, TRUE, msg);
 	
 	LOG_DEBUG("raid0_copy_data returned rc=%d, (sectors=%"PRIu64")\n", rc, sectors);
 	
@@ -2056,8 +2061,8 @@ static int raid0_do_expand(storage_object_t *region)
 	default:
 		/* Error, unwinding... */
 		if (sectors) {
-			sprintf(message_buffer, "RAID0 region %s failed to expand, restoring data...", region->name);
-			rc2 = raid0_copy_data(volume, org_vol, &sectors, FALSE, TRUE, message_buffer);
+			sprintf(msg, "RAID0 region %s failed to expand, restoring data...", region->name);
+			rc2 = raid0_copy_data(volume, org_vol, &sectors, FALSE, TRUE, msg);
 			if (rc2) {
 				LOG_CRITICAL("Error restoring data after expand failure.\n");
 			}
@@ -2106,6 +2111,7 @@ static int raid0_do_unwind_expansion(storage_object_t *region)
 	md_member_t *member;
 	int rc = 0;
 	boolean found = FALSE;
+	char msg[256];
 
 	LOG_ENTRY();
 
@@ -2136,8 +2142,8 @@ static int raid0_do_unwind_expansion(storage_object_t *region)
 	}
 	
 	if (!rc && sectors) {
-		sprintf(message_buffer, "RAID0 region %s failed to expand, restoring data...", region->name);
-		rc = raid0_copy_data(exp_vol, volume, &sectors, FALSE, TRUE, message_buffer);
+		sprintf(msg, "RAID0 region %s failed to expand, restoring data...", region->name);
+		rc = raid0_copy_data(exp_vol, volume, &sectors, FALSE, TRUE, msg);
 		if (rc) {
 			LOG_CRITICAL("Error restoring data after expand failure.\n");
 			goto error_free;
@@ -2204,6 +2210,7 @@ static int raid0_do_shrink(storage_object_t *region)
 	md_saved_info_t *info = NULL;
 	md_member_t *saved_member;
 	md_member_t *member;
+	char msg[256];
 
 	LOG_ENTRY();
 	
@@ -2273,10 +2280,10 @@ static int raid0_do_shrink(storage_object_t *region)
 	}
 	
 	
-	sprintf(message_buffer, "Shrinking RAID0 region %s...", region->name);
-	LOG_DEBUG("%s (sectors=%"PRIu64")\n",message_buffer, sectors);
+	sprintf(msg, "Shrinking RAID0 region %s...", region->name);
+	LOG_DEBUG("%s (sectors=%"PRIu64")\n", msg, sectors);
 	
-	rc = raid0_copy_data(org_vol, volume, &sectors, FALSE, TRUE, message_buffer);
+	rc = raid0_copy_data(org_vol, volume, &sectors, FALSE, TRUE, msg);
 	
 	LOG_DEBUG("raid0_copy_data returned rc=%d, (sectors=%"PRIu64")\n", rc, sectors);
 	
@@ -2306,10 +2313,9 @@ static int raid0_do_shrink(storage_object_t *region)
 	default:
 		/* Error, unwinding... */
 		if (sectors) {
-			sprintf(message_buffer,
-				"RAID0 region %s failed to shrink, restoring data...",
+			sprintf(msg, "RAID0 region %s failed to shrink, restoring data...",
 				region->name);
-			rc2 = raid0_copy_data(volume, org_vol, &sectors, FALSE, TRUE, message_buffer);
+			rc2 = raid0_copy_data(volume, org_vol, &sectors, FALSE, TRUE, msg);
 			if (rc2) {
 				LOG_CRITICAL("Error restoring data after shrink failure.\n");
 			}
@@ -3568,7 +3574,7 @@ int raid0_backup_metadata(storage_object_t *region)
 	volume->commit_flag |= MD_COMMIT_BACKUP_METADATA;
 	volume->commit_flag |= MD_COMMIT_DONT_CHECK_ACTIVE;
 	volume->flags |= MD_DIRTY;
-	rc = md_write_sbs_to_disk(volume); 
+	rc = md_write_sbs_to_disk(volume);
 	volume->commit_flag &= ~MD_COMMIT_BACKUP_METADATA;
 	volume->commit_flag &= ~MD_COMMIT_DONT_CHECK_ACTIVE;
 
@@ -3662,7 +3668,7 @@ static plugin_functions_t raid0_functions = {
  */
 
 plugin_record_t raid0_plugin_record = {
-	id:                     SetPluginID(EVMS_OEM_IBM, EVMS_REGION_MANAGER, 6),
+	id:                     EVMS_MD_RAID0_PLUGIN_ID,
 
 	version:                {major:      MAJOR_VERSION,
 				 minor:      MINOR_VERSION,
@@ -3675,9 +3681,9 @@ plugin_record_t raid0_plugin_record = {
 					       minor:      0,
 					       patchlevel: 0} },
 
-	short_name:             "MDRaid0RegMgr",
-	long_name:              "MD RAID0 Region Manager",
-	oem_name:               "IBM",
+	short_name:             EVMS_MD_RAID0_PLUGIN_SHORT_NAME,
+	long_name:              EVMS_MD_RAID0_PLUGIN_LONG_NAME,
+	oem_name:               EVMS_IBM_OEM_NAME,
 
 	functions:              {plugin: &raid0_functions},
 
