@@ -690,8 +690,11 @@ static void raid1_show_stale_disks(md_volume_t *vol)
 	md_member_t *member;
 	list_element_t iter;
 
+	LOG_ENTRY();
+
 	stale_disks = md_volume_count_stale_disks(vol);
 	if (stale_disks == 0) {
+		LOG_EXIT_VOID();
 		return;
 	}
 
@@ -706,11 +709,13 @@ static void raid1_show_stale_disks(md_volume_t *vol)
 	MESSAGE(_("Region %s : MD superblocks found in object(s) [%s] are not valid.  "
 		  "[%s] will not be activated and should be removed from the region.\n"),
 		vol->name, message_buffer, message_buffer);
+
+	LOG_EXIT_VOID();
 }
 
 static int raid1_init_region(
-	md_volume_t *vol, 
-	storage_object_t *region, 
+	md_volume_t *vol,
+	storage_object_t *region,
 	boolean final_call)
 {
 	int rc = 0;
@@ -787,7 +792,7 @@ static int raid1_create_region(md_volume_t * vol, list_anchor_t output_list, boo
 					   "  The number of raid disks for a full functional array is %d."
 					   "  The number of active disks is %d."),
 					 vol->name, vol->raid_disks, vol->active_disks);
-			md_queue_corrupt_message(vol->personality, message_buffer, length);
+			md_queue_corrupt_message(vol, message_buffer, length);
 		} else {
 			LOG_DEBUG("Volume %s does not have any active disks, delaying discovery.\n",
 				  vol->name);
@@ -924,7 +929,7 @@ retry:
 			vol->flags &= ~MD_NEEDS_REDISCOVER;
 			rc = raid1_rediscover_region(vol->region, final_call);
 			if (!(vol->flags & MD_NEEDS_REDISCOVER)) {
-				/* The region was rediscovered, 
+				/* The region was rediscovered,
 				 * go back to check everything again.
 				 */
 				goto retry;
@@ -1586,7 +1591,7 @@ static int raid1_commit_changes( storage_object_t * region,
 		saved_rc = rc;
 		rc = raid1_rediscover_region(region, TRUE);
 		if (!rc) {
-			/* 
+			/*
 			 * The region was rediscovered, volume pointer is now invalid.
 			 * The correct volume pointer is region->private_data.
 			 */
@@ -1963,17 +1968,17 @@ static int raid1_init_task( task_context_t * context )
 			context->selected_objects,0);
 		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].constraint_type = EVMS_Collection_List;
 		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].help = NULL;
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].name = 
+		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].name =
 			EngFncs->engine_strdup(RAID1_OPTION_SPARE_DISK_NAME );
 		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].min_len = 1;
 		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].max_len = EVMS_VOLUME_NAME_SIZE;
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].tip = 
+		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].tip =
 			EngFncs->engine_strdup(_("Object to use as a spare disk in the array") );
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].title = 
+		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].title =
 			EngFncs->engine_strdup(_("Spare Disk") );
 		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].type = EVMS_Type_String;
 		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].unit = EVMS_Unit_None;
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].value.s = 
+		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].value.s =
 			EngFncs->engine_alloc(EVMS_VOLUME_NAME_SIZE+1);
 		strcpy(context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].value.s, RAID1_NO_SELECTION);
 
@@ -3060,7 +3065,7 @@ static int raid1_get_plugin_functions(storage_object_t        * region,
 	} else {
 		if (volume->flags & MD_ARRAY_SYNCING) {
 			rc = raid1_rediscover_region(region, TRUE);
-			/* 
+			/*
 			 * If the region was rediscovered,
 			 * volume is invalid, must reset!!!
 			 */
@@ -3100,7 +3105,7 @@ static int raid1_can_be_added(md_volume_t * volume, storage_object_t * spare_can
 	}
 
 	/* The spare must not be too small. */
-	if (MD_CHUNK_ALIGN_NEW_SIZE_SECTORS(0, spare_candidate->size) 
+	if (MD_CHUNK_ALIGN_NEW_SIZE_SECTORS(0, spare_candidate->size)
 	    < md_volume_calc_size(volume)) {
 		LOG_ERROR("Object %s is too small"
 			  " to be a spare object for array %s.\n",
@@ -3248,7 +3253,7 @@ static int raid1_is_active(md_volume_t * vol, storage_object_t *obj)
 }
 
 
-/* 
+/*
  * raid1_plugin_function
  */
 static int raid1_plugin_function(storage_object_t * region,
@@ -3427,6 +3432,8 @@ static void free_region(storage_object_t *region)
 {
 	md_volume_t * volume = (md_volume_t *)region->private_data;
 
+	LOG_ENTRY();
+
 	md_free_volume(volume);
 
 	LOG_EXIT_VOID();
@@ -3454,7 +3461,7 @@ int raid1_backup_metadata(storage_object_t *region)
 	volume->commit_flag |= MD_COMMIT_BACKUP_METADATA;
 	volume->commit_flag |= MD_COMMIT_DONT_CHECK_ACTIVE;
 	volume->flags |= MD_DIRTY;
-	rc = md_write_sbs_to_disk(volume); 
+	rc = md_write_sbs_to_disk(volume);
 	volume->commit_flag &= ~MD_COMMIT_BACKUP_METADATA;
 	volume->commit_flag &= ~MD_COMMIT_DONT_CHECK_ACTIVE;
 
@@ -3529,7 +3536,7 @@ static plugin_functions_t raid1_functions = {
  */
 
 plugin_record_t raid1_plugin_record = {
-	id:                     SetPluginID(EVMS_OEM_IBM, EVMS_REGION_MANAGER, 5),
+	id:                     EVMS_MD_RAID1_PLUGIN_ID,
 
 	version:               {major:      MAJOR_VERSION,
 				minor:      MINOR_VERSION,
@@ -3542,9 +3549,9 @@ plugin_record_t raid1_plugin_record = {
 					       minor:      0,
 					       patchlevel: 0} },
 
-	short_name:             "MDRaid1RegMgr",
-	long_name:              "MD Raid 1 Region Manager",
-	oem_name:               "IBM",
+	short_name:             EVMS_MD_RAID1_PLUGIN_SHORT_NAME,
+	long_name:              EVMS_MD_RAID1_PLUGIN_LONG_NAME,
+	oem_name:               EVMS_IBM_OEM_NAME,
 
 	functions:              {plugin: &raid1_functions},
 
