@@ -865,6 +865,8 @@ static value_collection_t make_cluster_size_constraints(void) {
 
 	value_collection_t coll;
 
+	/* No entry/exit logs. */
+
 	coll.list = EngFncs->engine_alloc(sizeof(value_list_t) + sizeof(value_t) * 4);
 
 	if (coll.list != NULL) {
@@ -883,6 +885,8 @@ static value_collection_t make_MFT_zone_mult_constraints(void) {
 
 	value_collection_t coll;
 
+	/* No entry/exit logs. */
+
 	coll.list = EngFncs->engine_alloc(sizeof(value_list_t) + sizeof(value_t) * 4);
 
 	if (coll.list != NULL) {
@@ -1829,13 +1833,13 @@ static fsim_functions_t  fsim_ops = {
 +-------------------------------------------------------------------------------------*/
 
 static plugin_record_t  ntfs_plugrec = {
-	id:                               SetPluginID(EVMS_OEM_IBM, EVMS_FILESYSTEM_INTERFACE_MODULE, FS_TYPE_NTFS),
+	id:                               EVMS_NTFS_PLUGIN_ID,
 	version:                          {MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL},
 	required_engine_api_version:      {15, 0, 0},
 	required_plugin_api_version:      {fsim: {11, 0, 0}},
-	short_name:                       "NTFS",
-	long_name:                        "NTFS File System Interface Module",
-	oem_name:                         "IBM",
+	short_name:                       EVMS_NTFS_PLUGIN_SHORT_NAME,
+	long_name:                        EVMS_NTFS_PLUGIN_LONG_NAME,
+	oem_name:                         EVMS_IBM_OEM_NAME,
 	functions:                        {fsim: &fsim_ops},
 	container_functions:              NULL
 
