@@ -246,6 +246,8 @@ int has_ntfs_boot_sector(logical_volume_t * ev)
 	NTFS_BOOT_SECTOR * boot_sector;
 	int fd;
 
+	LOG_ENTRY();
+
 	boot_sector = EngFncs->engine_alloc(NTFS_BLOCK_SIZE);
 
 	if (boot_sector == NULL) {
@@ -269,10 +271,10 @@ int has_ntfs_boot_sector(logical_volume_t * ev)
 		if (is_boot_sector_ntfs(boot_sector)) {
 			goto finished;
 		} else {
-			LOG_DETAILS("Primary boot sector is not valid.");
+			LOG_DETAILS("Primary boot sector is not valid.\n");
 		}
 	} else
-		LOG_WARNING("Unable to read primary boot sector.");
+		LOG_WARNING("Unable to read primary boot sector.\n");
 
 	/* Try to read NT4+ backup boot sector at the end of the volume. */
 	if (EngFncs->read_volume(ev, fd, boot_sector, NTFS_BLOCK_SIZE, (ev->vol_size << EVMS_VSECTOR_SIZE_SHIFT) - NTFS_BLOCK_SIZE) == NTFS_BLOCK_SIZE) {
@@ -280,16 +282,16 @@ int has_ntfs_boot_sector(logical_volume_t * ev)
 			goto finished;
 		}
 	} else
-		LOG_WARNING("Unable to read NT4+ backup boot sector.");
+		LOG_WARNING("Unable to read NT4+ backup boot sector.\n");
 	/* Try to read NT3.51- backup boot sector in the middle of the volume. */
 	if (EngFncs->read_volume(ev, fd, boot_sector, NTFS_BLOCK_SIZE, (ev->vol_size << (EVMS_VSECTOR_SIZE_SHIFT - 1))) == NTFS_BLOCK_SIZE) {
 		if (is_boot_sector_ntfs(boot_sector)) {
 			goto finished;
 		} else {
-			LOG_DETAILS("Could not find a valid backup boot sector.");
+			LOG_DETAILS("Could not find a valid backup boot sector.\n");
 		}
 	} else
-		LOG_WARNING("Unable to read NT3.51- backup boot sector.");
+		LOG_WARNING("Unable to read NT3.51- backup boot sector.\n");
 
 	rc = EINVAL;
 finished:
@@ -372,6 +374,8 @@ int try_run(char * prog_name) {
 	int     status;
 	int     fds[2];
 
+	LOG_ENTRY();
+
 	/* Open a pipe to catch the program output that we don't care about. */
 	rc = pipe(fds);
 	if (rc) {
@@ -570,6 +574,7 @@ int try_run_get_version(char * prog_name, char * version) {
 	close(fds[0]);
 	close(fds[1]);
 
+	LOG_EXIT_INT(rc);
 	return(rc);
 }
 
@@ -891,6 +896,8 @@ static void handle_carriage_returns(char * buffer) {
 	char * p_cr;
 	char * p_nl;
 
+	/* No entry/exit logs. */
+
 	while ((p_cr = strrchr(buffer, '\r')) != NULL) {
 		if (p_cr == buffer) {
 			*p_cr = '\0';
