@@ -520,6 +520,11 @@ inline static int ogfs_get_super_block(logical_volume_t *volume,
 	if (rc == 0 && ogfs_mh->mh_type != OGFS_METATYPE_SB)
 		rc = EINVAL;
 		
+	if (rc == 0) {
+		ogfs_sb_t * ogfs_sb = (ogfs_sb_t *) ogfs_mh;
+		memset(ogfs_sb->sb_reserved, 0, sizeof(ogfs_sb->sb_reserved));
+	}
+
 	return rc;
 }
 
@@ -3129,9 +3134,7 @@ static fsim_functions_t ogfs_fsim_ops = {
 };
 
 plugin_record_t ogfs_plugin_record = {
-	.id			= SetPluginID(EVMS_OEM_IBM,
-				    EVMS_FILESYSTEM_INTERFACE_MODULE,
-				    FS_TYPE_OGFS),
+	.id			= EVMS_OGFS_PLUGIN_ID,
 	.version = {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -3149,9 +3152,9 @@ plugin_record_t ogfs_plugin_record = {
 			.patchlevel = 0
 		}
 	},
-	.short_name		= "OGFS",
-	.long_name		= "OpenGFS File System Interface Module",
-	.oem_name		= "IBM",
+	.short_name		= EVMS_OGFS_PLUGIN_SHORT_NAME,
+	.long_name		= EVMS_OGFS_PLUGIN_LONG_NAME,
+	.oem_name		= EVMS_IBM_OEM_NAME,
 	.functions  = {
 		.fsim = &ogfs_fsim_ops
 	},
