@@ -1806,9 +1806,7 @@ static fsim_functions_t fsim_ops = {
 };
 
 plugin_record_t reiser_plugin_record = {
-	.id = SetPluginID(EVMS_OEM_IBM,
-			  EVMS_FILESYSTEM_INTERFACE_MODULE,
-			  FS_TYPE_REISERFS),
+	.id = EVMS_REISER_PLUGIN_ID,
 	.version= {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -1826,9 +1824,9 @@ plugin_record_t reiser_plugin_record = {
 			.patchlevel	= 0
 		}
 	},
-	.short_name = "ReiserFS",
-	.long_name = "ReiserFS File System Interface Module",
-	.oem_name = "IBM",
+	.short_name = EVMS_REISER_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_REISER_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.fsim = &fsim_ops
 	},
