@@ -4,23 +4,23 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  *   Module: reiserfsim.h
  *
  */
 
-                   
+
 /********************
  ********************
  **                **
@@ -28,12 +28,11 @@
  **                **
  ********************
  ********************/
- 
+
 extern plugin_record_t reiser_plugin_record;
 extern plugin_record_t *my_plugin_record;
 extern engine_functions_t *EngFncs;
-                 
-#define FS_TYPE_REISERFS 9
+
 /**********************************
  **********************************
  **                              **
@@ -44,13 +43,13 @@ extern engine_functions_t *EngFncs;
 
 /* fsck.reiserfs, mkfs.reiserfs option counts */
 #define FSCK_OPTIONS_COUNT   1
-#define MKFS_OPTIONS_COUNT   3  
+#define MKFS_OPTIONS_COUNT   3
 
 /* fsck.reiserfs option array indices */
 #define FSCK_MODE_INDEX    0
 // MODE DEFINES
 #define FSCK_READONLY "Check Read-Only"
-#define FSCK_FIX "Fix"           
+#define FSCK_FIX "Fix"
 #define FSCK_REBUILD_TREE "Rebuild Tree"
 
 /* mkfs.reiserfs option array indices */
@@ -107,7 +106,7 @@ extern engine_functions_t *EngFncs;
 #define REISERFS_ERROR_FS    2
 
 /* struct reiserfs_super_block accessors/mutators
- * since this is a disk structure, it will always be in 
+ * since this is a disk structure, it will always be in
  * little endian format. */
 
 
@@ -217,7 +216,7 @@ struct reiserfs_super_block_v1
     u_int16_t sb_oid_cursize; 	/* 48 current size of object id array */
     u_int16_t sb_umount_state;	/* 50 this is set to 1 when filesystem was
 				   umounted, to 2 - when not */
-    
+
     int8_t s_magic[10]; 	/* 52 reiserfs magic string indicates that
 				   file system is reiserfs: "ReIsErFs" or
 				   "ReIsEr2Fs" or "ReIsEr3Fs" */
@@ -245,12 +244,12 @@ struct reiserfs_super_block_v1
 struct reiserfs_super_block
 {
 /*  0 */    struct reiserfs_super_block_v1 s_v1;
-/* 76 */    u_int32_t sb_inode_generation; 
+/* 76 */    u_int32_t sb_inode_generation;
 /* 76 */    u_int32_t s_flags;             /* Right now used only by inode-attributes, if enabled */
 /* 84 */    u_int8_t s_uuid[16];           /* filesystem unique identifier */
 /*100 */    u_int8_t s_label[16];          /* filesystem volume label */
 /*116 */    int8_t s_unused[88] ;          /* zero filled by mkreiserfs and reiserfs_convert_objectid_map_v1()
-                                            * so any additions must be updated there as well. */ 
+                                            * so any additions must be updated there as well. */
 /*204*/
 } __attribute__ ((__packed__));
 
