@@ -30,8 +30,6 @@
 
 #include <plugin.h>
 
-#include "replace.h"
-
 static plugin_record_t   replace_plugin_record;
 static plugin_record_t * my_plugin_record = &replace_plugin_record;
 
@@ -489,6 +487,9 @@ static void finish_replace_object_setup(replace_device_info_t * rep_dev_info) {
 
 	LOG_ENTRY();
 
+	MESSAGE("Found an unfinished replace of %s with %s.\n",
+		rep_dev_info->source_obj->name, rep_dev_info->target_obj->name);
+
 	if (rep_dev_info->mirror_info.dev_major != 0) {
 		/*
 		 * The copy is in progress.  Initialize the
@@ -501,8 +502,15 @@ static void finish_replace_object_setup(replace_device_info_t * rep_dev_info) {
 		init_copy_job(pd);
 
 		EngFncs->copy_setup(&pd->copy_job);
+
+		MESSAGE("The copying of the data is still in progress.\n");
+
+	} else {
+		MESSAGE("The copying of the data has finished.\n");
 	}
 
+	MESSAGE("The replace operation will be completed when the changes are saved.\n");
+
 	/*
 	 * We are finished building the replace object.
 	 * We can free the replace_device_info_t.
@@ -1070,7 +1078,7 @@ static int rep_commit_changes(storage_object_t * obj,
 	LOG_ENTRY();
 
 	/* Sanity checks */
-	if (obj->plugin->id != REPLACE_PLUGIN_ID) {
+	if (obj->plugin->id != EVMS_REPLACE_PLUGIN_ID) {
 		LOG_ERROR("Object %s is not managed by the Replace plug-in.\n", obj->name);
 		LOG_EXIT_INT(EINVAL);
 		return EINVAL;
@@ -1166,7 +1174,7 @@ static int rep_activate(storage_object_t * obj) {
 	LOG_ENTRY();
 
 	/* Sanity check */
-	if (obj->plugin->id != REPLACE_PLUGIN_ID) {
+	if (obj->plugin->id != EVMS_REPLACE_PLUGIN_ID) {
 		LOG_ERROR("Object %s is not managed by the Replace plug-in.\n", obj->name);
 		LOG_EXIT_INT(EINVAL);
 		return EINVAL;
@@ -1713,7 +1721,7 @@ static plugin_functions_t replace_functions = {
  */
 
 static plugin_record_t replace_plugin_record = {
-	id:         REPLACE_PLUGIN_ID,
+	id:         EVMS_REPLACE_PLUGIN_ID,
 
 	version:    {major:      MAJOR_VERSION,
 		     minor:      MINOR_VERSION,
@@ -1727,9 +1735,9 @@ static plugin_record_t replace_plugin_record = {
 					       minor:      1,
 					       patchlevel: 0}},
 
-	short_name: "Replace",
-	long_name:  "EVMS Replace",
-	oem_name:   "IBM",
+	short_name: EVMS_REPLACE_PLUGIN_SHORT_NAME,
+	long_name:  EVMS_REPLACE_PLUGIN_LONG_NAME,
+	oem_name:   EVMS_IBM_OEM_NAME,
 
 	functions:  {plugin: &replace_functions},
 
