@@ -29,9 +29,9 @@
 
 /* List of plugins whose volumes cannot be snapshotted. */
 static char * reject_plugins[] = {
-	"LocalDskMgr",
-	"MDRaid1RegMgr",
-	"MDRaid5RegMgr",
+	EVMS_DISK_PLUGIN_SHORT_NAME,
+	EVMS_MD_RAID1_PLUGIN_SHORT_NAME,
+	EVMS_MD_RAID5_PLUGIN_SHORT_NAME,
 	NULL
 };
 
