@@ -1521,9 +1521,7 @@ static plugin_functions_t snapshot_functions = {
 };
 
 plugin_record_t Snapshot_Plugin = {
-	.id = SetPluginID(IBM_OEM_ID,
-			  EVMS_ASSOCIATIVE_FEATURE,
-			  SNAPSHOT_FEATURE_ID),
+	.id = EVMS_SNAPSHOT_PLUGIN_ID,
 	.version = {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -1541,9 +1539,9 @@ plugin_record_t Snapshot_Plugin = {
 			.patchlevel	= 0
 		}
 	},
-	.short_name = "Snapshot",
-	.long_name = "Snapshot Feature",
-	.oem_name = "IBM",
+	.short_name = EVMS_SNAPSHOT_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_SNAPSHOT_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.plugin = &snapshot_functions
 	},
