@@ -1164,9 +1164,7 @@ static fsim_functions_t swap_ops = {
 };
 
 plugin_record_t swap_plugin_record = {
-	.id = SetPluginID(EVMS_OEM_IBM,
-			  EVMS_FILESYSTEM_INTERFACE_MODULE,
-			  FS_TYPE_SWAPFS),
+	.id = EVMS_SWAP_PLUGIN_ID,
 	.version = {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -1184,9 +1182,9 @@ plugin_record_t swap_plugin_record = {
 			.patchlevel	= 0
 		}
 	},
-	.short_name = "SWAPFS",
-	.long_name = "Swap File System Interface Module",
-	.oem_name = "IBM",
+	.short_name = EVMS_SWAP_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_SWAP_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.fsim = &swap_ops
 	},
