@@ -138,7 +138,7 @@ TokenType * GetScreenedToken(void)
 
         case 'A' : /* Acceptable, Add, All, Auto */
         case 'C' : /* Check, Children, Cluster, CM, Container, Containers, Create */
-        case 'D' : /* Defragment, Delete, Device, Disk, Disks, Distributed, DLM */
+        case 'D' : /* Delete, Device, Disk, Disks, Distributed, DLM */
         case 'E' : /* EI, EQ, End, Expand, Expandable, Extended */
         case 'F' : /* Feature, File, Filesystem, FSIM, Format, Freespace */
         case 'G' : /* GB, GT */
@@ -211,6 +211,15 @@ TokenType * GetScreenedToken(void)
               Convert_To_String = TRUE;
               break;
             case 3:
+              if ( strcmp(CurrentToken->TokenText, ActStr) == 0 )
+              {
+
+                /* We have a match.  Free TokenText and set it to ActStr. */
+                free(CurrentToken->TokenText);
+                CurrentToken->TokenText = ActStr;
+                break;
+
+              }
               if ( strcmp(CurrentToken->TokenText, AddStr) == 0 )
               {
 
@@ -265,6 +274,15 @@ TokenType * GetScreenedToken(void)
               Convert_To_String = TRUE;
               break;
             case 8:
+              if ( strcmp(CurrentToken->TokenText, ActivateStr) == 0 )
+              {
+
+                /* We have a match.  Free TokenText and set it to ActivateStr. */
+                free(CurrentToken->TokenText);
+                CurrentToken->TokenText = ActivateStr;
+                break;
+
+              }
               if ( strcmp(CurrentToken->TokenText, AllocateStr) == 0 )
               {
 
@@ -489,20 +507,11 @@ TokenType * GetScreenedToken(void)
           }
           break;
 
-        case 'D' : /* Defragment, Delete, Device, Disk, Disks, Distributed, DLM, DR */
+        case 'D' : /* Delete, Device, Disk, Disks, Distributed, DLM, DR */
 
           switch (CurrentToken->TokenLength)
           {
             case 2:
-              if ( strcmp(CurrentToken->TokenText, "DE") == 0 )
-              {
-
-                /* We have a match.  Free TokenText and set it to DefragmentStr. */
-                free(CurrentToken->TokenText);
-                CurrentToken->TokenText = DefragmentStr;
-                break;
-
-              }
               if ( strcmp(CurrentToken->TokenText, DrStr) == 0 )
               {
 
@@ -539,6 +548,15 @@ TokenType * GetScreenedToken(void)
               Convert_To_String = TRUE;
               break;
             case 5:
+              if ( strcmp(CurrentToken->TokenText, DeactStr) == 0 )
+              {
+
+                /* We have a match.  Free TokenText and set it to DeactStr. */
+                free(CurrentToken->TokenText);
+                CurrentToken->TokenText = DeactStr;
+                break;
+
+              }
               if ( strcmp(CurrentToken->TokenText, DisksStr) == 0 )
               {
 
@@ -574,12 +592,12 @@ TokenType * GetScreenedToken(void)
               Convert_To_String = TRUE;
               break;
             case 10:
-              if ( strcmp(CurrentToken->TokenText, DefragmentStr) == 0 )
+              if ( strcmp(CurrentToken->TokenText, DeactivateStr) == 0 )
               {
 
-                /* We have a match.  Free TokenText and set it to DefragmentStr. */
+                /* We have a match.  Free TokenText and set it to DeactivateStr. */
                 free(CurrentToken->TokenText);
-                CurrentToken->TokenText = DefragmentStr;
+                CurrentToken->TokenText = DeactivateStr;
                 break;
 
               }
@@ -996,6 +1014,18 @@ TokenType * GetScreenedToken(void)
                 CurrentToken->TokenText = MkfsStr;
                 break;
 
+              }
+              Convert_To_String = TRUE;
+              break;
+            case 5:
+              if ( strcmp(CurrentToken->TokenText, MountStr) == 0 )
+              {
+
+                /* We have a match.  Free TokenText and set it to MountStr. */
+                free(CurrentToken->TokenText);
+                CurrentToken->TokenText = MountStr;
+                break;
+
               }
               Convert_To_String = TRUE;
               break;
@@ -1546,6 +1576,18 @@ TokenType * GetScreenedToken(void)
                 CurrentToken->TokenText = UnMkfsStr;
                 break;
 
+              }
+              Convert_To_String = TRUE;
+              break;
+            case 7:
+              if ( strcmp(CurrentToken->TokenText, UnmountStr) == 0 )
+              {
+
+                /* We have a match.  Free TokenText and set it to UnmountStr. */
+                free(CurrentToken->TokenText);
+                CurrentToken->TokenText = UnmountStr;
+                break;
+
               }
               Convert_To_String = TRUE;
               break;
