@@ -4,16 +4,16 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  * Module: thing.c
@@ -33,12 +33,12 @@
 /*
  *
  *   void add_thing_to_selection_list (GtkCList *, object_handle_t, gboolean)
- *   
+ *
  *   Description:
  *      This routine appends a row to the standard selection window
  *      GtkCList with the information from the given object handle.
  *      It optionally can mark the appended entry as selected.
- * 
+ *
  *   Entry:
  *      widget        - address of the selection window GtkCList widget
  *      handle        - handle of object to place in selection window
@@ -102,7 +102,7 @@ gint add_thing_to_selection_list(GtkCList * clist, object_handle_t handle, gbool
 
 		/*
 		 * Associate things's handle with row data so that we can
-		 * use it when we invoke an operation based on the currently 
+		 * use it when we invoke an operation based on the currently
 		 * selected row.
 		 */
 
@@ -140,13 +140,13 @@ inline object_handle_t retrieve_object_handle_from_toplevel_widget(GtkWidget * w
 /*
  *
  *   void add_thing_as_selected_list_item (GtkCList *, gpointer)
- *   
+ *
  *   Description:
  *      This routine populates the standard selection window GtkCList
  *      with the information from one object handle. It also selects
  *      this single entry in the list so that the "Next" button is
  *      made active to complete an operation on the row.
- * 
+ *
  *   Entry:
  *      widget    - address of the selection window GtkCList widget
  *      user_data - contains handle of object to place in selection window
@@ -171,14 +171,14 @@ void add_thing_as_selected_list_item(GtkCList * clist, gpointer user_data)
 /*
  *
  *   GtkWidget* create_thing_details_window (extended_info_array_t *)
- *   
+ *
  *   Description:
  *      This routine creates a window with a close button and a notebook
  *      widget that contains plugin specific information. Each extended
  *      info structure is convereted to a widget that represents the data
  *      and the widgets are placed in a widget notebook which is placed
  *      in the window.
- * 
+ *
  *   Entry:
  *      handle        - the handle for the thing so we can get additional info
  *      extended_info - address of structure containing array of extended_info_t
@@ -412,14 +412,14 @@ void free_extra_extended_info(struct extra_extended_info *info)
 /*
  *
  *   void display_thing_details (object_handle_t, gchar *, gchar *)
- *   
+ *
  *   Description:
  *      This routine displays the plugin specific information on a thing.
- * 
+ *
  *   Entry:
  *      handle      - the handle of the thing to get extended info for
  *      field_name  - an optional field name to gather specific info on
- *      field_title - the title/description of the optional field name     
+ *      field_title - the title/description of the optional field name
  *
  *   Exit:
  *      Returns nothing.
@@ -467,12 +467,12 @@ void display_thing_details(object_handle_t handle, gchar * field_name, gchar * f
 /*
  *
  *   void on_display_thing_details_menu_item_activate (GtkMenuItem *, gpointer)
- *   
+ *
  *   Description:
  *      This routine displays the plugin specific information on the thing
  *      selected in one of the browser views. The information is retrieved
  *      through the evms_get_extended_info() API.
- * 
+ *
  *   Entry:
  *      menuitem  - menu item selected
  *      user_data - contains handle of the object we want extended info on
@@ -489,12 +489,12 @@ void on_display_thing_details_menu_item_activate(GtkMenuItem * menuitem, gpointe
 /*
  *
  *   void on_display_more_thing_details_button_clicked (GtkButton *, field_details *)
- *   
+ *
  *   Description:
  *      This routine displays the plugin specific information on the field
  *      for a thing if the field had the EVMS_EINFO_FLAGS_MORE_INFO_AVAILABLE
  *      flag set.
- * 
+ *
  *   Entry:
  *      button - id of the button clicked
  *      field  - contains reference info of the specific field
@@ -513,7 +513,7 @@ void on_display_more_thing_details_button_clicked(GtkButton * button, field_deta
 	 * Assign field->name to name if non-NULL and non-empty string.
 	 *
 	 * An empty field name equates to retrieving full info for the
-	 * object. This empty string trick is used by the 
+	 * object. This empty string trick is used by the
 	 * create_volume_pseudo_extended_info() routine to allow getting
 	 * toplevel extended info from an FSIM for a volume.
 	 */
@@ -526,12 +526,12 @@ void on_display_more_thing_details_button_clicked(GtkButton * button, field_deta
 /*
  *
  *   GtkWidget *create_multi_results_window (GtkWidget *, gchar *, GtkCList **)
- *   
+ *
  *   Description:
  *      This routine creates the multiple results window used for
  *      operations like remove and destroy where multiple selections
  *      and iterations of an operation are permitted.
- * 
+ *
  *   Entry:
  *      widget - a reference widget to obtain and append to the window list
  *      title  - the results window title
@@ -641,11 +641,11 @@ GtkWidget *create_multi_results_window(GtkWidget * widget, gchar * title, GtkCLi
 /*
  *
  *   inline gint append_row_to_results_clist (GtkCList *, object_handle_t)
- *   
+ *
  *   Description:
- *      This routine appends a new row in the clist contained in the 
+ *      This routine appends a new row in the clist contained in the
  *      multi-results window.
- * 
+ *
  *   Entry:
  *      clist  - the multiple results window GtkCList
  *      handle - the handle of the object we want to display info on
@@ -706,11 +706,11 @@ inline gint append_row_to_results_clist(GtkCList * clist, object_handle_t handle
 /*
  *
  *  inline void set_results_clist_row (GtkCList *, gint, gint, gchar *)
- *   
+ *
  *   Description:
  *      This routine updates the results column text for the given
  *      row in the multi-results window list.
- * 
+ *
  *   Entry:
  *      clist - the multiple results window GtkCList
  *      row   - the row in the clist to update
@@ -739,11 +739,11 @@ inline void set_results_clist_row(GtkCList * clist, gint row, gint rc, gchar * s
 /*
  *
  *  void display_multi_results_window (GtkWidget *, gchar *)
- *   
+ *
  *   Description:
  *      This routine displays the results window and destroys the selection
  *      window if the operation was successful.
- * 
+ *
  *   Entry:
  *      window - the multiple results window
  *      status - the status message for the status bar
@@ -772,11 +772,9 @@ void display_multi_results_window(GtkWidget * window, gchar * status)
  */
 handle_array_t *duplicate_handle_array(handle_array_t * old)
 {
-	int count;
 	handle_array_t *new;
 
-	count = old->count > 0 ? old->count - 1 : 0;
-	new = g_memdup(old, sizeof(handle_array_t) + (sizeof(object_handle_t) * count));
+	new = g_memdup(old, sizeof(handle_array_t) + (sizeof(object_handle_t) * old->count));
 
 	return new;
 }
@@ -787,7 +785,7 @@ handle_array_t *duplicate_handle_array(handle_array_t * old)
  *	@array2: the second handle array
  *
  *	This routine takes the address of two handle arrays, allocates space
- *	to copy the handles in both into one array and returns the new array. 
+ *	to copy the handles in both into one array and returns the new array.
  */
 handle_array_t *merge_handle_array(handle_array_t * array1, handle_array_t * array2)
 {
